@@ -744,7 +744,7 @@ namespace Magick
     // NOTE: setting a DirectClass image to PseudoClass will result in
     // the loss of color information if the number of colors in the
     // image is greater than the maximum palette size (either 256 or
-    // 65536 entries depending on the value of QuantumDepth when
+    // 65536 entries depending on the value of MAGICKCORE_QUANTUM_DEPTH when
     // ImageMagick was built).
     void            classType ( const ClassType class_ );
     ClassType       classType ( void ) const;
@@ -1219,27 +1219,27 @@ typedef struct _ImageStatistics
     //////////////////////////////////////////////////////////////////////
 
 
-    // Construct with MagickLib::Image and default options
-    Image ( MagickLib::Image* image_ );
+    // Construct with MagickCore::Image and default options
+    Image ( MagickCore::Image* image_ );
 
     // Retrieve Image*
-    MagickLib::Image*& image( void );
-    const MagickLib::Image* constImage( void ) const;
+    MagickCore::Image*& image( void );
+    const MagickCore::Image* constImage( void ) const;
 
     // Retrieve Options*
     Options* options( void );
     const Options*  constOptions( void ) const;
 
     // Retrieve ImageInfo*
-    MagickLib::ImageInfo * imageInfo( void );
-    const MagickLib::ImageInfo * constImageInfo( void ) const;
+    MagickCore::ImageInfo * imageInfo( void );
+    const MagickCore::ImageInfo * constImageInfo( void ) const;
 
     // Retrieve QuantizeInfo*
-    MagickLib::QuantizeInfo * quantizeInfo( void );
-    const MagickLib::QuantizeInfo * constQuantizeInfo( void ) const;
+    MagickCore::QuantizeInfo * quantizeInfo( void );
+    const MagickCore::QuantizeInfo * constQuantizeInfo( void ) const;
 
     // Replace current image (reference counted)
-    MagickLib::Image* replaceImage ( MagickLib::Image* replacement_ );
+    MagickCore::Image* replaceImage ( MagickCore::Image* replacement_ );
 
     // Prepare to update image (copy if reference > 1)
     void            modifyImage ( void );
