@@ -305,6 +305,8 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
   Image *image,*palette;
   ImageInfo *clone_info;
+  MagickBooleanType
+    proceed;
   MagickBooleanType status;
 
   MagickOffsetType
