@@ -53,6 +53,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/monitor-private.h"
 #include "magick/option.h"
 #include "magick/quantum-private.h"
 #include "magick/static.h"
@@ -198,6 +199,7 @@ static MagickBooleanType WriteINFOImage(const ImageInfo *image_info,
         if (text != (char *) NULL)
           {
             (void) WriteBlobString(image,text);
+            (void) WriteBlobString(image,"\n");
             text=DestroyString(text);
           }
       }
