@@ -53,6 +53,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/monitor-private.h"
 #include "magick/option.h"
 #include "magick/property.h"
 #include "magick/quantum-private.h"
@@ -172,6 +173,10 @@ static Image *ReadIPLImage(const ImageInfo *image_info,ExceptionInfo *exception)
   Declare variables 
    */
   Image *image;
+
+  MagickBooleanType
+    proceed;
+
   MagickBooleanType status;
   register PixelPacket *q;
   unsigned char magick[12], *pixels;
