@@ -60,6 +60,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/monitor-private.h"
 #include "magick/option.h"
 #include "magick/profile.h"
 #include "magick/property.h"
@@ -1169,14 +1170,8 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
           }
     if (SyncImagePixels(image) == MagickFalse)
       break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(LoadImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    if (SetImageProgress(image,LoadImageTag,y,image->rows) == MagickFalse)
+      break;
   }
   /*
     Free jpeg resources.
@@ -1962,14 +1957,8 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
             p++;
           }
           (void) jpeg_write_scanlines(&jpeg_info,scanline,1);
-          if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-              (QuantumTick(y,image->rows) != MagickFalse))
-            {
-              status=image->progress_monitor(SaveImageTag,y,image->rows,
-                image->client_data);
-              if (status == MagickFalse)
-                break;
-            }
+          if (SetImageProgress(image,SaveImageTag,y,image->rows) == MagickFalse)
+            break;
         }
       else
         if ((jpeg_info.in_color_space == JCS_RGB) ||
@@ -1988,14 +1977,9 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
               p++;
             }
             (void) jpeg_write_scanlines(&jpeg_info,scanline,1);
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(SaveImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            status=SetImageProgress(image,SaveImageTag,y,image->rows);
+            if (status == MagickFalse)
+              break;
           }
         else
           for (y=0; y < (long) image->rows; y++)
@@ -2017,14 +2001,9 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
               p++;
             }
             (void) jpeg_write_scanlines(&jpeg_info,scanline,1);
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(SaveImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            status=SetImageProgress(image,SaveImageTag,y,image->rows);
+            if (status == MagickFalse)
+              break;
           }
     }
   else
@@ -2041,14 +2020,8 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
           p++;
         }
         (void) jpeg_write_scanlines(&jpeg_info,scanline,1);
-        if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-            (QuantumTick(y,image->rows) != MagickFalse))
-          {
-            status=image->progress_monitor(SaveImageTag,y,image->rows,
-              image->client_data);
-            if (status == MagickFalse)
-              break;
-          }
+        if (SetImageProgress(image,SaveImageTag,y,image->rows) == MagickFalse)
+          break;
       }
     else
       if ((jpeg_info.in_color_space == JCS_RGB) ||
@@ -2067,14 +2040,8 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
             p++;
           }
           (void) jpeg_write_scanlines(&jpeg_info,scanline,1);
-          if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-              (QuantumTick(y,image->rows) != MagickFalse))
-            {
-              status=image->progress_monitor(SaveImageTag,y,image->rows,
-                image->client_data);
-              if (status == MagickFalse)
-                break;
-            }
+          if (SetImageProgress(image,SaveImageTag,y,image->rows) == MagickFalse)
+            break;
         }
       else
         for (y=0; y < (long) image->rows; y++)
@@ -2100,14 +2067,8 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
             p++;
           }
           (void) jpeg_write_scanlines(&jpeg_info,scanline,1);
-          if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-              (QuantumTick(y,image->rows) != MagickFalse))
-            {
-              status=image->progress_monitor(SaveImageTag,y,image->rows,
-                image->client_data);
-              if (status == MagickFalse)
-                break;
-            }
+          if (SetImageProgress(image,SaveImageTag,y,image->rows) == MagickFalse)
+            break;
         }
   if (y == (long) image->rows)
     jpeg_finish_compress(&jpeg_info);
