@@ -13,7 +13,7 @@
 %                                                                             %
 %                              Software Design                                %
 %                              Jaroslav Fojtik                                %
-%                                 June 2001                                   %
+%                                2001-2008                                    %
 %                                                                             %
 %                                                                             %
 %  Permission is hereby granted, free of charge, to any person obtaining a    %
@@ -436,6 +436,10 @@ void *CacheBlock, *DecompressBlock;
 z_stream zip_info;
 FILE *mat_file;
 size_t magick_size;
+
+MagickBooleanType
+  proceed;
+
 int status;
 
   if(clone_info==NULL) return NULL;
@@ -474,14 +478,14 @@ int status;
   zip_info.total_out = 0;
   while(Size>0 && !EOFBlob(orig))
   {    
-    magick_size = ReadBlob(orig, (Size<16384)?Size:16384, CacheBlock);
-    zip_info.next_in = CacheBlock;
-    zip_info.avail_in = magick_size;    
+    magick_size = ReadBlob(orig, (Size<16384)?Size:16384, (unsigned char *) CacheBlock);
+    zip_info.next_in = (Bytef *) CacheBlock;
+    zip_info.avail_in = (uInt) magick_size;    
 
     while(zip_info.avail_in>0)
     {
       zip_info.avail_out = 4096;    
-      zip_info.next_out = DecompressBlock;
+      zip_info.next_out = (Bytef *) DecompressBlock;
       status = inflate(&zip_info,Z_NO_FLUSH);      
       fwrite(DecompressBlock, 4096-zip_info.avail_out, 1, mat_file);
 
@@ -559,6 +563,10 @@ static Image *ReadMATImage(const ImageInfo *image_info,ExceptionInfo *exception)
   Image *image, *image2=NULL,
    *rotated_image;
   PixelPacket *q;
+
+  MagickBooleanType
+    proceed;
+
   unsigned int status;
   MATHeader MATLAB_HDR;
   unsigned long size;  
@@ -812,7 +820,7 @@ MATLAB_KO: ThrowReaderException(CorruptImageError,"ImproperImageHeader");
     }  
 
   /* ----- Load raster data ----- */
-    BImgBuff = AcquireQuantumMemory((size_t) (ldblk),sizeof(unsigned char *));    /* Ldblk was set in the check phase */
+    BImgBuff = (unsigned char *) AcquireQuantumMemory((size_t) (ldblk),sizeof(unsigned char *));    /* Ldblk was set in the check phase */
     if (BImgBuff == NULL)
       goto NoMemory;
 
@@ -1103,6 +1111,10 @@ static MagickBooleanType WriteMATImage(const ImageInfo *image_info,Image *image)
   long y;
   unsigned z;
   const PixelPacket *p;
+
+  MagickBooleanType
+    proceed;
+
   unsigned int status;
   int logging;
   unsigned long DataSize;
