@@ -56,6 +56,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/monitor-private.h"
 #include "magick/option.h"
 #include "magick/pixel.h"
 #include "magick/profile.h"
@@ -1306,13 +1307,10 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
             return((Image *) NULL);
           }
         image=SyncNextImageInList(image);
-        if (image->progress_monitor != (MagickProgressMonitor) NULL)
-          {
-            status=image->progress_monitor(LoadImagesTag,TellBlob(image),
-              GetBlobSize(image),image->client_data);
-            if (status == MagickFalse)
-              break;
-          }
+        status=SetImageProgress(image,LoadImagesTag,TellBlob(image),
+          GetBlobSize(image));
+        if (status == MagickFalse)
+          break;
       }
   } while (c != EOF);
   (void) CloseBlob(image);
@@ -2166,28 +2164,19 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
           break;
         }
       }
-      if (image->previous == (Image *) NULL)
-        if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-            (QuantumTick(y,image->rows) != MagickFalse))
-          {
-            status=image->progress_monitor(SaveImageTag,y,image->rows,
-              image->client_data);
-            if (status == MagickFalse)
-              break;
-          }
+      if ((image->previous == (Image *) NULL) &&
+          (SetImageProgress(image,SaveImageTag,y,image->rows) == MagickFalse))
+        break;
     }
     quantum_info=DestroyQuantumInfo(quantum_info);
     compress_pixels=(unsigned char *) RelinquishMagickMemory(compress_pixels);
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
-    if (image->progress_monitor != (MagickProgressMonitor) NULL)
-      {
-        status=image->progress_monitor(SaveImagesTag,scene,
-          GetImageListLength(image),image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    status=SetImageProgress(image,SaveImagesTag,scene,
+      GetImageListLength(image));
+    if (status == MagickFalse)
+      break;
     scene++;
   } while (image_info->adjoin != MagickFalse);
   (void) CloseBlob(image);
