@@ -53,6 +53,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/monitor-private.h"
 #include "magick/pixel-private.h"
 #include "magick/property.h"
 #include "magick/quantum-private.h"
@@ -466,14 +467,11 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         image->type=BilevelType;
         break;
@@ -531,14 +529,11 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         image->type=GrayscaleType;
         if (scale != (Quantum *) NULL)
@@ -599,14 +594,11 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         if (scale != (Quantum *) NULL)
           scale=(Quantum *) RelinquishMagickMemory(scale);
@@ -640,14 +632,11 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         SetQuantumImageType(image,quantum_type);
         quantum_info=DestroyQuantumInfo(quantum_info);
@@ -706,14 +695,11 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         SetQuantumImageType(image,quantum_type);
         quantum_info=DestroyQuantumInfo(quantum_info);
@@ -798,14 +784,11 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
               q++;
           }
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         quantum_info=DestroyQuantumInfo(quantum_info);
         if (type != UndefinedType)
@@ -1004,14 +987,11 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         SetQuantumImageType(image,quantum_type);
         quantum_info=DestroyQuantumInfo(quantum_info);
@@ -1044,14 +1024,11 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         SetQuantumImageType(image,quantum_type);
         quantum_info=DestroyQuantumInfo(quantum_info);
@@ -1094,13 +1071,10 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
             return((Image *) NULL);
           }
         image=SyncNextImageInList(image);
-        if (image->progress_monitor != (MagickProgressMonitor) NULL)
-          {
-            status=image->progress_monitor(LoadImagesTag,TellBlob(image),
-              GetBlobSize(image),image->client_data);
-            if (status == MagickFalse)
-              break;
-          }
+        status=SetImageProgress(image,LoadImagesTag,TellBlob(image),
+          GetBlobSize(image));
+        if (status == MagickFalse)
+          break;
       }
   } while ((count == 1) && (format == 'P'));
   (void) CloseBlob(image);
@@ -1476,14 +1450,11 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
             p++;
           }
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(SaveImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,SaveImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         if (q != pixels)
           {
@@ -1531,14 +1502,11 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
             p++;
           }
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(SaveImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,SaveImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         if (q != pixels)
           {
@@ -1587,14 +1555,11 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
             p++;
           }
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(SaveImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,SaveImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         if (q != pixels)
           {
@@ -1624,14 +1589,11 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
           if (count != (ssize_t) length)
             break;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(SaveImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,SaveImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         quantum_info=DestroyQuantumInfo(quantum_info);
         break;
@@ -1704,14 +1666,11 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
           if (count != (ssize_t) length)
             break;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(SaveImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,SaveImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         quantum_info=DestroyQuantumInfo(quantum_info);
         break;
@@ -1785,14 +1744,11 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
           if (count != (ssize_t) length)
             break;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(SaveImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,SaveImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         quantum_info=DestroyQuantumInfo(quantum_info);
         break;
@@ -1947,14 +1903,11 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
           if (count != (ssize_t) length)
             break;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(SaveImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,SaveImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         quantum_info=DestroyQuantumInfo(quantum_info);
         break;
@@ -1979,14 +1932,11 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
           length=ExportQuantumPixels(image,quantum_info,quantum_type,pixels);
           (void) WriteBlob(image,length,pixels);
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(SaveImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,SaveImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         quantum_info=DestroyQuantumInfo(quantum_info);
         break;
@@ -1995,13 +1945,10 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
-    if (image->progress_monitor != (MagickProgressMonitor) NULL)
-      {
-        status=image->progress_monitor(SaveImagesTag,scene,
-          GetImageListLength(image),image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    status=SetImageProgress(image,SaveImagesTag,scene,
+      GetImageListLength(image));
+    if (status == MagickFalse)
+      break;
     scene++;
   } while (image_info->adjoin != MagickFalse);
   (void) CloseBlob(image);
