@@ -57,6 +57,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/monitor-private.h"
 #include "magick/option.h"
 #include "magick/property.h"
 #include "magick/quantum.h"
@@ -90,7 +91,7 @@ typedef struct _ExifInfo
     tag,
     type;
 
-  char
+  const char
     *property;
 } ExifInfo;
 
@@ -1038,14 +1039,11 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         break;
       }
@@ -1090,14 +1088,11 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         break;
       }
@@ -1144,14 +1139,11 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
               break;
           }
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         break;
       }
@@ -1191,14 +1183,11 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         break;
       }
@@ -1291,14 +1280,11 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         tile_pixels=(uint32 *) RelinquishMagickMemory(tile_pixels);
         break;
@@ -1306,9 +1292,12 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
       case ReadGenericMethod:
       default:
       {
-        register unsigned char
+        register uint32
           *p;
 
+        uint32
+          *pixels;
+
         /*
           Convert TIFF image to DirectClass MIFF image.
         */
@@ -1319,6 +1308,13 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             TIFFClose(tiff);
             ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
           }
+        pixels=(uint32 *) AcquireQuantumMemory(image->columns,image->rows*
+          sizeof(uint32));
+        if (pixels == (uint32 *) NULL)
+          {
+            TIFFClose(tiff);
+            ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
+          }
         (void) TIFFReadRGBAImage(tiff,(uint32) image->columns,
           (uint32) image->rows,(uint32 *) pixels,0);
         /*
@@ -1344,15 +1340,13 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(LoadImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,LoadImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
+        pixels=(uint32 *) RelinquishMagickMemory(pixels);
         break;
       }
     }
@@ -1397,13 +1391,10 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             return((Image *) NULL);
           }
         image=SyncNextImageInList(image);
-        if (image->progress_monitor != (MagickProgressMonitor) NULL)
-          {
-            status=image->progress_monitor(LoadImagesTag,(MagickOffsetType)
-              image->scene-1,image->scene,image->client_data);
-            if (status == MagickFalse)
-              break;
-          }
+        status=SetImageProgress(image,LoadImagesTag,image->scene-1,
+          image->scene);
+        if (status == MagickFalse)
+          break;
       }
     quantum_info=DestroyQuantumInfo(quantum_info);
   } while (status == MagickTrue);
@@ -2492,14 +2483,11 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
               if (TIFFWritePixels(tiff,&tiff_info,y,0,image) == -1)
                 break;
               if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(y,image->rows) != MagickFalse))
-                  {
-                    status=image->progress_monitor(SaveImageTag,y,image->rows,
-                      image->client_data);
-                    if (status == MagickFalse)
-                      break;
-                  }
+                {
+                  status=SetImageProgress(image,SaveImageTag,y,image->rows);
+                  if (status == MagickFalse)
+                    break;
+                }
             }
             break;
           }
@@ -2520,10 +2508,9 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
               if (TIFFWritePixels(tiff,&tiff_info,y,0,image) == -1)
                 break;
             }
-            if (image->progress_monitor != (MagickProgressMonitor) NULL)
+            if (image->previous == (Image *) NULL)
               {
-                status=image->progress_monitor(LoadImageTag,100,400,
-                  image->client_data);
+                status=SetImageProgress(image,SaveImageTag,100,400);
                 if (status == MagickFalse)
                   break;
               }
@@ -2538,10 +2525,9 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
               if (TIFFWritePixels(tiff,&tiff_info,y,1,image) == -1)
                 break;
             }
-            if (image->progress_monitor != (MagickProgressMonitor) NULL)
+            if (image->previous == (Image *) NULL)
               {
-                status=image->progress_monitor(LoadImageTag,200,400,
-                  image->client_data);
+                status=SetImageProgress(image,SaveImageTag,200,400);
                 if (status == MagickFalse)
                   break;
               }
@@ -2556,10 +2542,9 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
               if (TIFFWritePixels(tiff,&tiff_info,y,2,image) == -1)
                 break;
             }
-            if (image->progress_monitor != (MagickProgressMonitor) NULL)
+            if (image->previous == (Image *) NULL)
               {
-                status=image->progress_monitor(LoadImageTag,300,400,
-                  image->client_data);
+                status=SetImageProgress(image,SaveImageTag,300,400);
                 if (status == MagickFalse)
                   break;
               }
@@ -2575,10 +2560,9 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
                 if (TIFFWritePixels(tiff,&tiff_info,y,3,image) == -1)
                   break;
               }
-            if (image->progress_monitor != (MagickProgressMonitor) NULL)
+            if (image->previous == (Image *) NULL)
               {
-                status=image->progress_monitor(LoadImageTag,400,400,
-                  image->client_data);
+                status=SetImageProgress(image,SaveImageTag,400,400);
                 if (status == MagickFalse)
                   break;
               }
@@ -2606,14 +2590,11 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
           if (TIFFWritePixels(tiff,&tiff_info,y,0,image) == -1)
             break;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(SaveImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,SaveImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         break;
       }
@@ -2675,14 +2656,11 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
           if (TIFFWritePixels(tiff,&tiff_info,y,0,image) == -1)
             break;
           if (image->previous == (Image *) NULL)
-            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                (QuantumTick(y,image->rows) != MagickFalse))
-              {
-                status=image->progress_monitor(SaveImageTag,y,image->rows,
-                  image->client_data);
-                if (status == MagickFalse)
-                  break;
-              }
+            {
+              status=SetImageProgress(image,SaveImageTag,y,image->rows);
+              if (status == MagickFalse)
+                break;
+            }
         }
         break;
       }
@@ -2697,13 +2675,10 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
     image=SyncNextImageInList(image);
     if (image == (Image *) NULL)
       break;
-    if (image->progress_monitor != (MagickProgressMonitor) NULL)
-      {
-        status=image->progress_monitor(SaveImagesTag,scene,
-          GetImageListLength(image),image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    status=SetImageProgress(image,SaveImagesTag,scene,
+      GetImageListLength(image));
+    if (status == MagickFalse)
+      break;
     scene++;
     quantum_info=DestroyQuantumInfo(quantum_info);
   } while (image_info->adjoin != MagickFalse);
