@@ -10,7 +10,7 @@
 %                             UUU   R  R   LLLLL                              %
 %                                                                             %
 %                                                                             %
-%                        Retrieve An Image Via a URL.                         %
+%                        Retrieve An Image Via URL.                         %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
@@ -81,7 +81,7 @@
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  ReadURLImage retrieves an image via a URL, decodes the image, and returns
+%  ReadURLImage retrieves an image via URL, decodes the image, and returns
 %  it.  It allocates the memory necessary for the new Image structure and
 %  returns a pointer to the new image.
 %
