@@ -1035,11 +1035,11 @@ static MagickBooleanType RenderType(Image *image,const DrawInfo *draw_info,
   if (draw_info->font != (char *) NULL)
     {
       if (*draw_info->font == '@')
-        return(RenderFreetype(image,draw_info,(char *) NULL,offset,metrics));
+        return(RenderFreetype(image,draw_info,draw_info->encoding,offset,metrics));
       if (*draw_info->font == '-')
         return(RenderX11(image,draw_info,offset,metrics));
       if (IsAccessible(draw_info->font) != MagickFalse)
-        return(RenderFreetype(image,draw_info,(char *) NULL,offset,metrics));
+        return(RenderFreetype(image,draw_info,draw_info->encoding,offset,metrics));
       type_info=GetTypeInfo(draw_info->font,&image->exception);
       if (type_info == (const TypeInfo *) NULL)
         (void) ThrowMagickException(&image->exception,GetMagickModule(),
@@ -1065,7 +1065,7 @@ static MagickBooleanType RenderType(Image *image,const DrawInfo *draw_info,
       draw_info->stretch,draw_info->weight,&image->exception);
   if (type_info == (const TypeInfo *) NULL)
     {
-      status=RenderFreetype(image,draw_info,(const char *) NULL,offset,
+      status=RenderFreetype(image,draw_info,draw_info->encoding,offset,
         metrics);
       return(status);
     }
@@ -1349,7 +1349,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
       if ((flags & SigmaValue) == 0)
         resolution.y=resolution.x;
     }
-  (void) FT_Set_Char_Size(face,(FT_F26Dot6) (64.0*draw_info->pointsize),
+  status=FT_Set_Char_Size(face,(FT_F26Dot6) (64.0*draw_info->pointsize),
     (FT_F26Dot6) (64.0*draw_info->pointsize),(FT_UInt) resolution.x,
     (FT_UInt) resolution.y);
   metrics->pixels_per_em.x=face->size->metrics.x_ppem;
