@@ -41,7 +41,9 @@ typedef enum
   MaskVirtualPixelMethod,
   BlackVirtualPixelMethod,
   GrayVirtualPixelMethod,
-  WhiteVirtualPixelMethod
+  WhiteVirtualPixelMethod,
+  HorizontalTileVirtualPixelMethod,
+  VerticalTileVirtualPixelMethod
 } VirtualPixelMethod;
 
 typedef struct _ViewInfo
