@@ -130,9 +130,12 @@ static const char
     "  <coder magick=\"K\" name=\"GRAY\" />"
     "  <coder magick=\"LOGO\" name=\"MAGICK\" />"
     "  <coder magick=\"M2V\" name=\"MPEG\" />"
+    "  <coder magick=\"M4V\" name=\"MPEG\" />"
     "  <coder magick=\"M\" name=\"GRAY\" />"
     "  <coder magick=\"MNG\" name=\"PNG\" />"
+    "  <coder magick=\"MOV\" name=\"MPEG\" />"
     "  <coder magick=\"MPG\" name=\"MPEG\" />"
+    "  <coder magick=\"MP4\" name=\"MPEG\" />"
     "  <coder magick=\"MPRI\" name=\"MPR\" />"
     "  <coder magick=\"MRW\" name=\"DNG\" />"
     "  <coder magick=\"MSVG\" name=\"SVG\" />"
