@@ -107,7 +107,7 @@ extern MagickExport MagickBooleanType
     ExceptionInfo *),
   QueryMagickColor(const char *,MagickPixelPacket *,ExceptionInfo *),
   QueryMagickColorname(const Image *,const MagickPixelPacket *,
-    const ComplianceType,const MagickBooleanType,char *,ExceptionInfo *);
+    const ComplianceType,char *,ExceptionInfo *);
 
 extern MagickExport unsigned long
   GetNumberColors(const Image *,FILE *,ExceptionInfo *);
