@@ -54,6 +54,7 @@
 #include "magick/gem.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/monitor-private.h"
 #include "magick/pixel-private.h"
 #include "magick/quantize.h"
 #include "magick/quantum.h"
@@ -151,7 +152,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
     *indexes;
 
   MagickBooleanType
-    status;
+    proceed;
 
   PrimaryInfo
     primary_info,
@@ -882,14 +883,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         }
         if (SyncImagePixels(image) == MagickFalse)
           break;
-        if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-            (QuantumTick(y,image->rows) != MagickFalse))
-          {
-            status=image->progress_monitor(RGBTransformImageTag,y,image->rows,
-              image->client_data);
-            if (status == MagickFalse)
-              break;
-          }
+        proceed=SetImageProgress(image,RGBTransformImageTag,y,image->rows);
+        if (proceed == MagickFalse)
+          break;
       }
       break;
     }
@@ -1129,7 +1125,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
     y;
 
   MagickBooleanType
-    status;
+    proceed;
 
   MagickPixelPacket
     pixel;
@@ -1749,11 +1745,11 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
             case YCCColorspace:
             {
 #if !defined(MAGICKCORE_HDRI_SUPPORT)
-              pixel.red=ScaleCharToQuantum(YCCMap[RoundToYCC(
+              pixel.red=(MagickRealType) ScaleCharToQuantum(YCCMap[RoundToYCC(
                 255.0*QuantumScale*pixel.red)]);
-              pixel.green=ScaleCharToQuantum(YCCMap[RoundToYCC(
+              pixel.green=(MagickRealType) ScaleCharToQuantum(YCCMap[RoundToYCC(
                 255.0*QuantumScale*pixel.green)]);
-              pixel.blue=ScaleCharToQuantum(YCCMap[RoundToYCC(
+              pixel.blue=(MagickRealType) ScaleCharToQuantum(YCCMap[RoundToYCC(
                 255.0*QuantumScale*pixel.blue)]);
 #endif
               break;
@@ -1790,14 +1786,9 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         }
         if (SyncImagePixels(image) == MagickFalse)
           break;
-        if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-            (QuantumTick(y,image->rows) != MagickFalse))
-          {
-            status=image->progress_monitor(TransformRGBImageTag,y,image->rows,
-              image->client_data);
-            if (status == MagickFalse)
-              break;
-          }
+        proceed=SetImageProgress(image,TransformRGBImageTag,y,image->rows);
+        if (proceed == MagickFalse)
+          break;
       }
       break;
     }
