@@ -52,6 +52,7 @@
 #include "magick/list.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/monitor-private.h"
 #include "magick/option.h"
 #include "magick/resource_.h"
 #include "magick/string_.h"
@@ -431,7 +432,7 @@ MagickExport MagickBooleanType HuffmanDecodeImage(Image *image)
     y;
 
   MagickBooleanType
-    status;
+    proceed;
 
   register IndexPacket
     *indexes;
@@ -632,14 +633,9 @@ MagickExport MagickBooleanType HuffmanDecodeImage(Image *image)
     }
     if (SyncImagePixels(image) == MagickFalse)
       break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(LoadImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    proceed=SetImageProgress(image,LoadImageTag,y,image->rows);
+    if (proceed == MagickFalse)
+      break;
     y++;
   }
   image->rows=(unsigned long) MagickMax((size_t) y-3,1);
@@ -722,7 +718,7 @@ MagickExport MagickBooleanType HuffmanEncodeImage(const ImageInfo *image_info,
     *huffman_image;
 
   MagickBooleanType
-    status;
+    proceed;
 
   register IndexPacket
     *indexes;
@@ -854,14 +850,12 @@ MagickExport MagickBooleanType HuffmanEncodeImage(const ImageInfo *image_info,
     OutputBit(1);
     q=scanline;
     if (GetPreviousImageInList(huffman_image) == (Image *) NULL)
-      if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-          (QuantumTick(y,huffman_image->rows) != MagickFalse))
-        {
-          status=image->progress_monitor(LoadImageTag,y,huffman_image->rows,
-            image->client_data);
-          if (status == MagickFalse)
-            break;
-        }
+      {
+        proceed=SetImageProgress(huffman_image,LoadImageTag,y,
+          huffman_image->rows);
+        if (proceed == MagickFalse)
+          break;
+      }
   }
   /*
     End of page.
@@ -1085,7 +1079,6 @@ MagickExport MagickBooleanType Huffman2DEncodeImage(const ImageInfo *image_info,
 %    o pixels: the address of an unsigned array of characters containing the
 %      pixels to compress.
 %
-%
 */
 MagickExport MagickBooleanType LZWEncodeImage(Image *image,const size_t length,
   unsigned char *pixels)
@@ -1248,7 +1241,6 @@ MagickExport MagickBooleanType LZWEncodeImage(Image *image,const size_t length,
 %    o pixels: the address of an unsigned array of characters containing the
 %      pixels to compress.
 %
-%
 */
 MagickExport MagickBooleanType PackbitsEncodeImage(Image *image,
   const size_t length,unsigned char *pixels)
