@@ -729,8 +729,8 @@ MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
         /*
           Search $HOME/.magick.
         */
-        (void) FormatMagickString(path,MaxTextExtent,"%s%s%s",home,
-          *home == '/' ? "/.magick" : "",DirectorySeparator);
+        (void) FormatMagickString(path,MaxTextExtent,"%s%s.magick%s",home,
+          DirectorySeparator,DirectorySeparator);
         (void) AppendValueToLinkedList(paths,ConstantString(path));
         home=DestroyString(home);
       }
