@@ -137,6 +137,7 @@ MagickExport MagickBooleanType ClutImageChannel(Image *image,
 
   long
     adjust,
+    progress,
     y;
 
   MagickBooleanType
@@ -160,6 +161,7 @@ MagickExport MagickBooleanType ClutImageChannel(Image *image,
     Clut image.
   */
   status=MagickTrue;
+  progress=0;
   adjust=clut_image->interpolate == IntegerInterpolatePixel ? 0 : 1;
   resample_filter=AcquireResampleFilterThreadSet(clut_image,&image->exception);
   image_view=AcquireCacheViewThreadSet(image);
@@ -261,8 +263,16 @@ MagickExport MagickBooleanType ClutImageChannel(Image *image,
     }
     if (SyncCacheView(image_view[id]) == MagickFalse)
       status=MagickFalse;
-    if (SetImageProgress(image,ClutImageTag,y,image->rows) == MagickFalse)
-      status=MagickFalse;
+    if (image->progress_monitor != (MagickProgressMonitor) NULL)
+      {
+        MagickBooleanType
+          proceed;
+
+        #pragma omp critical
+        proceed=SetImageProgress(image,ClutImageTag,progress++,image->rows);
+        if (proceed == MagickFalse)
+          status=MagickFalse;
+      }
   }
   image_view=DestroyCacheViewThreadSet(image_view);
   resample_filter=DestroyResampleFilterThreadSet(resample_filter);
@@ -337,6 +347,7 @@ MagickExport MagickBooleanType ContrastImage(Image *image,
     sign;
 
   long
+    progress,
     y;
 
   MagickBooleanType
@@ -366,6 +377,7 @@ MagickExport MagickBooleanType ContrastImage(Image *image,
     Contrast enhance image.
   */
   status=MagickTrue;
+  progress=0;
   image_view=AcquireCacheViewThreadSet(image);
   #pragma omp parallel for
   for (y=0; y < (long) image->rows; y++)
@@ -393,8 +405,16 @@ MagickExport MagickBooleanType ContrastImage(Image *image,
     }
     if (SyncCacheView(image_view[id]) == MagickFalse)
       status=MagickFalse;
-    if (SetImageProgress(image,ContrastImageTag,y,image->rows) == MagickFalse)
-      status=MagickFalse;
+    if (image->progress_monitor != (MagickProgressMonitor) NULL)
+      {
+        MagickBooleanType
+          proceed;
+
+        #pragma omp critical
+        proceed=SetImageProgress(image,ContrastImageTag,progress++,image->rows);
+        if (proceed == MagickFalse)
+          status=MagickFalse;
+      }
   }
   image_view=DestroyCacheViewThreadSet(image_view);
   return(status);
@@ -489,6 +509,7 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
     intensity;
 
   long
+    progress,
     y;
 
   MagickBooleanType
@@ -807,15 +828,13 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
     Stretch image.
   */
   status=MagickTrue;
+  progress=0;
   #pragma omp parallel for
   for (y=0; y < (long) image->rows; y++)
   {
     IndexPacket
       *indexes;
 
-    MagickBooleanType
-      progress;
-
     register long
       id,
       x;
@@ -870,9 +889,17 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
     }
     if (SyncCacheView(image_view[id]) == MagickFalse)
       status=MagickFalse;
-    progress=SetImageProgress(image,ContrastStretchImageTag,y,image->rows);
-    if (progress == MagickFalse)
-      status=MagickFalse;
+    if (image->progress_monitor != (MagickProgressMonitor) NULL)
+      {
+        MagickBooleanType
+          proceed;
+
+        #pragma omp critical
+        proceed=SetImageProgress(image,ContrastStretchImageTag,progress++,
+          image->rows);
+        if (proceed == MagickFalse)
+          status=MagickFalse;
+      }
   }
   image_view=DestroyCacheViewThreadSet(image_view);
   stretch_map=(MagickPixelPacket *) RelinquishMagickMemory(stretch_map);
@@ -938,6 +965,7 @@ MagickExport Image *EnhanceImage(const Image *image,ExceptionInfo *exception)
     *enhance_image;
 
   long
+    progress,
     y;
 
   MagickBooleanType
@@ -974,6 +1002,7 @@ MagickExport Image *EnhanceImage(const Image *image,ExceptionInfo *exception)
     Enhance image.
   */
   status=MagickTrue;
+  progress=0;
   (void) ResetMagickMemory(&zero,0,sizeof(zero));
   image_view=AcquireCacheViewThreadSet(image);
   enhance_view=AcquireCacheViewThreadSet(enhance_image);
@@ -1048,8 +1077,16 @@ MagickExport Image *EnhanceImage(const Image *image,ExceptionInfo *exception)
     }
     if (SyncCacheView(enhance_view[id]) == MagickFalse)
       status=MagickFalse;
-    if (SetImageProgress(image,EnhanceImageTag,y,image->rows) == MagickFalse)
-      status=MagickFalse;
+    if (image->progress_monitor != (MagickProgressMonitor) NULL)
+      {
+        MagickBooleanType
+          proceed;
+
+        #pragma omp critical
+        proceed=SetImageProgress(image,EnhanceImageTag,progress++,image->rows);
+        if (proceed == MagickFalse)
+          status=MagickFalse;
+      }
   }
   enhance_view=DestroyCacheViewThreadSet(enhance_view);
   enhance_view=DestroyCacheViewThreadSet(image_view);
@@ -1094,6 +1131,7 @@ MagickExport MagickBooleanType EqualizeImageChannel(Image *image,
 #define EqualizeImageTag  "Equalize/Image"
 
   long
+    progress,
     y;
 
   MagickBooleanType
@@ -1246,6 +1284,7 @@ MagickExport MagickBooleanType EqualizeImageChannel(Image *image,
     Equalize image.
   */
   status=MagickTrue;
+  progress=0;
   image_view=AcquireCacheViewThreadSet(image);
   #pragma omp parallel for
   for (y=0; y < (long) image->rows; y++)
@@ -1291,8 +1330,16 @@ MagickExport MagickBooleanType EqualizeImageChannel(Image *image,
     }
     if (SyncCacheView(image_view[id]) == MagickFalse)
       status=MagickFalse;
-    if (SetImageProgress(image,EqualizeImageTag,y,image->rows) == MagickFalse)
-      status=MagickFalse;
+    if (image->progress_monitor != (MagickProgressMonitor) NULL)
+      {
+        MagickBooleanType
+          proceed;
+
+        #pragma omp critical
+        proceed=SetImageProgress(image,EqualizeImageTag,progress++,image->rows);
+        if (proceed == MagickFalse)
+          status=MagickFalse;
+      }
   }
   image_view=DestroyCacheViewThreadSet(image_view);
   equalize_map=(MagickPixelPacket *) RelinquishMagickMemory(equalize_map);
@@ -1375,6 +1422,7 @@ MagickExport MagickBooleanType GammaImageChannel(Image *image,
 #define GammaCorrectImageTag  "GammaCorrect/Image"
 
   long
+    progress,
     y;
 
   MagickBooleanType
@@ -1442,13 +1490,11 @@ MagickExport MagickBooleanType GammaImageChannel(Image *image,
     Gamma-correct image.
   */
   status=MagickTrue;
+  progress=0;
   image_view=AcquireCacheViewThreadSet(image);
   #pragma omp parallel for
   for (y=0; y < (long) image->rows; y++)
   {
-    MagickBooleanType
-      progress;
-
     register IndexPacket
       *indexes;
 
@@ -1492,9 +1538,17 @@ MagickExport MagickBooleanType GammaImageChannel(Image *image,
     }
     if (SyncImagePixels(image) == MagickFalse)
       status=MagickFalse;
-    progress=SetImageProgress(image,GammaCorrectImageTag,y,image->rows);
-    if (progress == MagickFalse)
-      status=MagickFalse;
+    if (image->progress_monitor != (MagickProgressMonitor) NULL)
+      {
+        MagickBooleanType
+          proceed;
+
+        #pragma omp critical
+        proceed=SetImageProgress(image,GammaCorrectImageTag,progress++,
+          image->rows);
+        if (proceed == MagickFalse)
+          status=MagickFalse;
+      }
   }
   image_view=DestroyCacheViewThreadSet(image_view);
   gamma_map=(MagickRealType *) RelinquishMagickMemory(gamma_map);
@@ -1640,6 +1694,7 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
   pow(((double) (x)-black_point)/(white_point-black_point),1.0/gamma)))
 
   long
+    progress,
     y;
 
   MagickBooleanType
@@ -1678,6 +1733,7 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
     Level image.
   */
   status=MagickTrue;
+  progress=0;
   image_view=AcquireCacheViewThreadSet(image);
   #pragma omp parallel for
   for (y=0; y < (long) image->rows; y++)
@@ -1719,8 +1775,16 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
     }
     if (SyncCacheView(image_view[id]) == MagickFalse)
       status=MagickFalse;
-    if (SetImageProgress(image,LevelImageTag,y,image->rows) == MagickFalse)
-      status=MagickFalse;
+    if (image->progress_monitor != (MagickProgressMonitor) NULL)
+      {
+        MagickBooleanType
+          proceed;
+
+        #pragma omp critical
+        proceed=SetImageProgress(image,LevelImageTag,progress++,image->rows);
+        if (proceed == MagickFalse)
+          status=MagickFalse;
+      }
   }
   image_view=DestroyCacheViewThreadSet(image_view);
   return(status);
@@ -1779,6 +1843,7 @@ MagickExport MagickBooleanType LevelizeImageChannel(Image *image,
   black_point))
 
   long
+    progress,
     y;
 
   MagickBooleanType
@@ -1817,6 +1882,7 @@ MagickExport MagickBooleanType LevelizeImageChannel(Image *image,
     Level image.
   */
   status=MagickTrue;
+  progress=0;
   image_view=AcquireCacheViewThreadSet(image);
   #pragma omp parallel for
   for (y=0; y < (long) image->rows; y++)
@@ -1858,8 +1924,16 @@ MagickExport MagickBooleanType LevelizeImageChannel(Image *image,
     }
     if (SyncCacheView(image_view[id]) == MagickFalse)
       status=MagickFalse;
-    if (SetImageProgress(image,LevelizeImageTag,y,image->rows) == MagickFalse)
-      status=MagickFalse;
+    if (image->progress_monitor != (MagickProgressMonitor) NULL)
+      {
+        MagickBooleanType
+          proceed;
+
+        #pragma omp critical
+        proceed=SetImageProgress(image,LevelizeImageTag,progress++,image->rows);
+        if (proceed == MagickFalse)
+          status=MagickFalse;
+      }
   }
   return(status);
 }
@@ -1912,7 +1986,7 @@ MagickBooleanType LevelImageColors(Image *image,const ChannelType channel,
 {
 #define LevelColorImageTag  "LevelColor/Image"
 
-  MagickBooleanType
+  MagickStatusType
     status;
 
   /*
@@ -1927,40 +2001,40 @@ MagickBooleanType LevelImageColors(Image *image,const ChannelType channel,
   if ( invert == MagickFalse ) {
     if ((channel & RedChannel) != 0)
       status |= LevelImageChannel(image,RedChannel,
-           black_color->red,white_color->red, (double)1.0);
+        black_color->red,white_color->red, (double)1.0);
     if ((channel & GreenChannel) != 0)
       status |= LevelImageChannel(image,GreenChannel,
-           black_color->green,white_color->green, (double)1.0);
+        black_color->green,white_color->green, (double)1.0);
     if ((channel & BlueChannel) != 0)
       status |= LevelImageChannel(image,BlueChannel,
-           black_color->blue,white_color->blue, (double)1.0);
+        black_color->blue,white_color->blue, (double)1.0);
     if ((channel & OpacityChannel) != 0)
       status |= LevelImageChannel(image,OpacityChannel,
-           black_color->opacity,white_color->opacity, (double)1.0);
+        black_color->opacity,white_color->opacity, (double)1.0);
     if (((channel & IndexChannel) != 0) &&
         (image->colorspace == CMYKColorspace))
       status |= LevelImageChannel(image,IndexChannel,
-           black_color->index,white_color->index, (double)1.0);
+        black_color->index,white_color->index, (double)1.0);
   }
   else {
     if ((channel & RedChannel) != 0)
       status |= LevelizeImageChannel(image,RedChannel,
-           black_color->red,white_color->red, (double)1.0);
+        black_color->red,white_color->red, (double)1.0);
     if ((channel & GreenChannel) != 0)
       status |= LevelizeImageChannel(image,GreenChannel,
-           black_color->green,white_color->green, (double)1.0);
+        black_color->green,white_color->green, (double)1.0);
     if ((channel & BlueChannel) != 0)
       status |= LevelizeImageChannel(image,BlueChannel,
-           black_color->blue,white_color->blue, (double)1.0);
+        black_color->blue,white_color->blue, (double)1.0);
     if ((channel & OpacityChannel) != 0)
       status |= LevelizeImageChannel(image,OpacityChannel,
-           black_color->opacity,white_color->opacity, (double)1.0);
+        black_color->opacity,white_color->opacity, (double)1.0);
     if (((channel & IndexChannel) != 0) &&
         (image->colorspace == CMYKColorspace))
       status |= LevelizeImageChannel(image,IndexChannel,
-           black_color->index,white_color->index, (double)1.0);
+        black_color->index,white_color->index, (double)1.0);
   }
-  return(status);
+  return(status == 0 ? MagickFalse : MagickTrue);
 }
 
 /*
@@ -2185,6 +2259,7 @@ MagickExport MagickBooleanType ModulateImage(Image *image,const char *modulate)
     geometry_info;
 
   long
+    progress,
     y;
 
   MagickBooleanType
@@ -2254,6 +2329,7 @@ MagickExport MagickBooleanType ModulateImage(Image *image,const char *modulate)
     Modulate image.
   */
   status=MagickTrue;
+  progress=0;
   image_view=AcquireCacheViewThreadSet(image);
   #pragma omp parallel for
   for (y=0; y < (long) image->rows; y++)
@@ -2302,8 +2378,16 @@ MagickExport MagickBooleanType ModulateImage(Image *image,const char *modulate)
     }
     if (SyncCacheView(image_view[id]) == MagickFalse)
       status=MagickFalse;
-    if (SetImageProgress(image,ModulateImageTag,y,image->rows) == MagickFalse)
-      status=MagickFalse;
+    if (image->progress_monitor != (MagickProgressMonitor) NULL)
+      {
+        MagickBooleanType
+          proceed;
+
+        #pragma omp critical
+        proceed=SetImageProgress(image,ModulateImageTag,progress++,image->rows);
+        if (proceed == MagickFalse)
+          status=MagickFalse;
+      }
   }
   image_view=DestroyCacheViewThreadSet(image_view);
   return(status);
@@ -2356,6 +2440,7 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
 #define NegateImageTag  "Negate/Image"
 
   long
+    progress,
     y;
 
   MagickBooleanType
@@ -2398,6 +2483,7 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
     Negate image.
   */
   status=MagickTrue;
+  progress=0;
   image_view=AcquireCacheViewThreadSet(image);
   if (grayscale != MagickFalse)
     {
@@ -2446,8 +2532,17 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
         }
         if (SyncCacheView(image_view[id]) == MagickFalse)
           status=MagickFalse;
-        if (SetImageProgress(image,NegateImageTag,y,image->rows) == MagickFalse)
-          status=MagickFalse;
+        if (image->progress_monitor != (MagickProgressMonitor) NULL)
+          {
+            MagickBooleanType
+              proceed;
+
+            #pragma omp critical
+            proceed=SetImageProgress(image,NegateImageTag,progress++,
+              image->rows);
+            if (proceed == MagickFalse)
+              status=MagickFalse;
+          }
       }
       image_view=DestroyCacheViewThreadSet(image_view);
       return(MagickTrue);
@@ -2495,8 +2590,16 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
     }
     if (SyncCacheView(image_view[id]) == MagickFalse)
       status=MagickFalse;
-    if (SetImageProgress(image,NegateImageTag,y,image->rows) == MagickFalse)
-      status=MagickFalse;
+    if (image->progress_monitor != (MagickProgressMonitor) NULL)
+      {
+        MagickBooleanType
+          proceed;
+
+        #pragma omp critical
+        proceed=SetImageProgress(image,NegateImageTag,progress++,image->rows);
+        if (proceed == MagickFalse)
+          status=MagickFalse;
+      }
   }
   image_view=DestroyCacheViewThreadSet(image_view);
   return(status);
@@ -2623,6 +2726,7 @@ MagickExport MagickBooleanType SigmoidalContrastImageChannel(Image *image,
 #define SigmoidalContrastImageTag  "SigmoidalContrast/Image"
 
   long
+    progress,
     y;
 
   MagickBooleanType
@@ -2699,13 +2803,11 @@ MagickExport MagickBooleanType SigmoidalContrastImageChannel(Image *image,
     Sigmoidal-contrast enhance image.
   */
   status=MagickTrue;
+  progress=0;
   image_view=AcquireCacheViewThreadSet(image);
   #pragma omp parallel for
   for (y=0; y < (long) image->rows; y++)
   {
-    MagickBooleanType
-      progress;
-
     register IndexPacket
       *indexes;
 
@@ -2744,9 +2846,17 @@ MagickExport MagickBooleanType SigmoidalContrastImageChannel(Image *image,
     }
     if (SyncCacheView(image_view[id]) == MagickFalse)
       status=MagickFalse;
-    progress=SetImageProgress(image,SigmoidalContrastImageTag,y,image->rows);
-    if (progress == MagickFalse)
-      status=MagickFalse;
+    if (image->progress_monitor != (MagickProgressMonitor) NULL)
+      {
+        MagickBooleanType
+          proceed;
+
+        #pragma omp critical
+        proceed=SetImageProgress(image,SigmoidalContrastImageTag,progress++,
+          image->rows);
+        if (proceed == MagickFalse)
+          status=MagickFalse;
+      }
   }
   image_view=DestroyCacheViewThreadSet(image_view);
   sigmoidal_map=(MagickRealType *) RelinquishMagickMemory(sigmoidal_map);
