@@ -16,7 +16,7 @@
 %                                 July 2000                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -79,6 +79,7 @@ static const char
     "  <magic name=\"CGM\" offset=\"0\" target=\"BEGMF\" />"
     "  <magic name=\"DCM\" offset=\"128\" target=\"DICM\" />"
     "  <magic name=\"DCX\" offset=\"0\" target=\"\\261\\150\\336\\72\" />"
+    "  <magic name=\"DDS\" offset=\"0\" target=\"DDS \" />"
     "  <magic name=\"DIB\" offset=\"0\" target=\"\\050\\000\" />"
     "  <magic name=\"DJVU\" offset=\"0\" target=\"AT&TFORM\" />"
     "  <magic name=\"DOT\" offset=\"0\" target=\"digraph\" />"
@@ -223,7 +224,7 @@ MagickExport void DestroyMagicList(void)
     magic_list=DestroyLinkedList(magic_list,DestroyMagicElement);
   instantiate_magic=MagickFalse;
   RelinquishSemaphoreInfo(magic_semaphore);
-  magic_semaphore=DestroySemaphoreInfo(magic_semaphore);
+  DestroySemaphoreInfo(&magic_semaphore);
 }
 
 /*
@@ -250,7 +251,7 @@ MagickExport void DestroyMagicList(void)
 %    o magic: A binary string generally representing the first few characters
 %      of the image file or blob.
 %
-%    o length: The length of the binary signature.
+%    o length: the length of the binary signature.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -829,7 +830,7 @@ static MagickBooleanType LoadMagicList(const char *xml,const char *filename,
 %
 %  A description of each parameter follows:
 %
-%    o filename: The font file name.
+%    o filename: the font file name.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -837,7 +838,7 @@ static MagickBooleanType LoadMagicList(const char *xml,const char *filename,
 static MagickBooleanType LoadMagicLists(const char *filename,
   ExceptionInfo *exception)
 {
-#if defined(UseEmbeddableMagick)
+#if defined(MAGICKCORE_EMBEDDABLE_SUPPORT)
   return(LoadMagicList(MagicMap,"built-in",0,exception));
 #else
   char
