@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -24,11 +24,11 @@ extern "C" {
 
 #include "magick/magick-config.h"
 
-#if !defined(QuantumDepth)
-#define QuantumDepth  16
+#if !defined(MAGICKCORE_QUANTUM_DEPTH)
+#define MAGICKCORE_QUANTUM_DEPTH  16
 #endif
 
-#if defined(__WINDOWS__)
+#if defined(__WINDOWS__) && !defined(__MINGW32__)
 #  define MagickLLConstant(c)  (MagickOffsetType) (c ## i64)
 #  define MagickULLConstant(c)  (MagickSizeType) (c ## ui64)
 #else
@@ -36,51 +36,54 @@ extern "C" {
 #  define MagickULLConstant(c)  (MagickSizeType) (c ## ULL)
 #endif
 
-#if (QuantumDepth == 8)
+#if (MAGICKCORE_QUANTUM_DEPTH == 8)
 #define MagickEpsilon  1.0e-6
 #define MagickHuge     1.0e6
 #define MaxColormapSize  256UL
 #define MaxMap  255UL
-#define QuantumRange  255UL
 
 typedef float MagickRealType;
-#if defined(UseHDRI)
+#if defined(MAGICKCORE_HDRI_SUPPORT)
+#define QuantumRange  255.0
 typedef float Quantum;
 #define QuantumFormat  "%g"
 #else
+#define QuantumRange  255UL
 typedef unsigned char Quantum;
 #define QuantumFormat  "%u"
 #endif
 typedef unsigned long QuantumAny;
-#elif (QuantumDepth == 16)
+#elif (MAGICKCORE_QUANTUM_DEPTH == 16)
 #define MagickEpsilon  1.0e-10
 #define MagickHuge     1.0e12
 #define MaxColormapSize  65536UL
 #define MaxMap  65535UL
-#define QuantumRange  65535UL
 
 typedef double MagickRealType;
-#if defined(UseHDRI)
+#if defined(MAGICKCORE_HDRI_SUPPORT)
+#define QuantumRange  65535.0
 typedef float Quantum;
 #define QuantumFormat  "%g"
 #else
+#define QuantumRange  65535UL
 typedef unsigned short Quantum;
 #define QuantumFormat  "%u"
 #endif
 typedef unsigned long QuantumAny;
-#elif (QuantumDepth == 32)
+#elif (MAGICKCORE_QUANTUM_DEPTH == 32)
 #define MagickEpsilon  1.0e-10
 #define MagickHuge     1.0e12
 #define MaxColormapSize  65536UL
 #define MaxMap  65535UL
-#define QuantumRange  4294967295UL
 
-#if defined(HAVE_LONG_DOUBLE)
+#if defined(MAGICKCORE_HAVE_LONG_DOUBLE)
+#define QuantumRange  4294967295.0
 typedef long double MagickRealType;
 #else
+#define QuantumRange  4294967295UL
 typedef double MagickRealType;
 #endif
-#if defined(UseHDRI)
+#if defined(MAGICKCORE_HDRI_SUPPORT)
 typedef float Quantum;
 #define QuantumFormat  "%g"
 #else
@@ -88,25 +91,26 @@ typedef unsigned int Quantum;
 #define QuantumFormat  "%u"
 #endif
 typedef unsigned long QuantumAny;
-#elif (QuantumDepth == 64) && defined(HAVE_LONG_DOUBLE)
+#elif (MAGICKCORE_QUANTUM_DEPTH == 64) && defined(MAGICKCORE_HAVE_LONG_DOUBLE)
 #define MagickEpsilon  1.0e-10
 #define MagickHuge     1.0e12
 #define MaxColormapSize  65536UL
 #define MaxMap  65535UL
-#define QuantumRange  MagickULLConstant(18446744073709551615)
 
 typedef long double MagickRealType;
-#if defined(UseHDRI)
+#if defined(MAGICKCORE_HDRI_SUPPORT)
+#define QuantumRange  18446744073709551615.0
 typedef double Quantum;
 #define QuantumFormat  "%g"
 #else
+#define QuantumRange  MagickULLConstant(18446744073709551615)
 typedef unsigned long long Quantum;
 #define QuantumFormat  "%llu"
 #endif
 typedef unsigned long long QuantumAny;
 #else
 #if !defined(_CH_)
-# error "Specified value of QuantumDepth is not supported"
+# error "Specified value of MAGICKCORE_QUANTUM_DEPTH is not supported"
 #endif
 #endif
 #define MaxRGB  QuantumRange  /* deprecated */
@@ -116,7 +120,7 @@ typedef unsigned long long QuantumAny;
 */
 typedef unsigned int MagickStatusType;
 #if !defined(__WINDOWS__)
-#if (SIZEOF_LONG_LONG == 8)
+#if (MAGICKCORE_SIZEOF_UNSIGNED_LONG_LONG == 8)
 typedef long long MagickOffsetType;
 typedef unsigned long long MagickSizeType;
 #define MagickSizeFormat  "%10llu"
