@@ -707,8 +707,8 @@ static MagickBooleanType GetMagickModulePath(const char *filename,
         /*
           Search $HOME/.magick.
         */
-        (void) FormatMagickString(path,MaxTextExtent,"%s%s%s%s",home,
-          *home == '/' ? "/.magick" : "",DirectorySeparator,filename);
+        (void) FormatMagickString(path,MaxTextExtent,"%s%s.magick%s%s",home,
+          DirectorySeparator,DirectorySeparator,filename);
         home=DestroyString(home);
         if (IsAccessible(path) != MagickFalse)
           return(MagickTrue);
@@ -934,7 +934,12 @@ MagickExport MagickBooleanType InvokeDynamicImageFilter(const char *tag,
   /*
     Close the module.
   */
-  (void) lt_dlclose(handle);
+  if (lt_dlclose(handle) != 0)
+    {
+      (void) ThrowMagickException(exception,GetMagickModule(),ModuleWarning,
+        "UnableToCloseModule","`%s': %s",name,lt_dlerror());
+      return(MagickFalse);
+    }
   return(MagickTrue);
 }
 
