@@ -492,7 +492,7 @@ MagickExport int NTExitLibrary(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  NTGatherRandomData() gathers random data and returns it.
+%  NTGatherRandomData() gathers random datand returns it.
 %
 %  The format of the GatherRandomData method is:
 %
@@ -1302,50 +1302,57 @@ MagickExport void *NTMapMemory(char *address,size_t length,int protection,
   int flags,int file,MagickOffsetType offset)
 {
   DWORD
-    high,
-    low,
-    mode;
+    access_mode,
+    high_length,
+    high_offset,
+    low_length,
+    low_offset,
+    protection_mode;
 
   HANDLE
     file_handle,
-    file_map;
+    map_handle;
 
   void
     *map;
 
-  mode=0;
-  if ((protection & PROT_WRITE) != 0)
+  access_mode=0;
+  file_handle=INVALID_HANDLE_VALUE;
+  low_length=(DWORD) (length & 0xFFFFFFFFUL);
+  high_length=(DWORD) ((((MagickOffsetType) length) >> 32) & 0xFFFFFFFFUL);
+  map_handle=INVALID_HANDLE_VALUE;
+  map=(void *) NULL;
+  low_offset=(DWORD) (offset & 0xFFFFFFFFUL);
+  high_offset=(DWORD) ((offset >> 32) & 0xFFFFFFFFUL);
+  protection_mode=0;
+  if (protection & PROT_WRITE)
     {
-      mode=PAGE_READWRITE;
-      if ((flags & MAP_PRIVATE) != 0)
-        mode=PAGE_WRITECOPY;
+      access_mode=FILE_MAP_WRITE;
+      if (!(flags & MAP_PRIVATE))
+        protection_mode=PAGE_READWRITE;
+      else
+        {
+          access_mode=FILE_MAP_COPY;
+          protection_mode=PAGE_WRITECOPY;
+        }
     }
   else
-    if ((protection & PROT_READ) != 0)
-      mode=PAGE_READONLY;
-  file_handle=INVALID_HANDLE_VALUE;
-  if ((file != -1) || ((flags & MAP_ANONYMOUS) == 0))
+    if (protection & PROT_READ)
+      {
+        access_mode=FILE_MAP_READ;
+        protection_mode=PAGE_READONLY;
+      }
+  if ((file == -1) && (flags & MAP_ANONYMOUS))
+    file_handle=INVALID_HANDLE_VALUE;
+  else
     file_handle=(HANDLE) _get_osfhandle(file);
-  low=(DWORD) (length & 0xffffffffUL);
-  high=(DWORD) ((((MagickOffsetType) length) >> 32) & 0xffffffffUL);
-  file_map=CreateFileMapping(file_handle,0,mode,high,low,0);
-  map=(void *) NULL;
-  if (file_map != (HANDLE) NULL)
+  map_handle=CreateFileMapping(file_handle,0,protection_mode,high_length,
+    low_length,0);
+  if (map_handle)
     {
-      mode=0;
-      if ((protection & PROT_WRITE) != 0)
-        {
-          mode=FILE_MAP_WRITE;
-          if ((flags & MAP_PRIVATE) != 0)
-            mode=FILE_MAP_COPY;
-        }
-      else
-        if ((protection & PROT_READ) != 0)
-          mode=FILE_MAP_READ;
-      low=(DWORD) (offset & 0xffffffffUL);
-      high=(DWORD) ((offset >> 32) & 0xffffffffUL);
-      map=(void *) MapViewOfFile(file_map,mode,high,low,length);
-      CloseHandle(file_map);
+      map=(void *) MapViewOfFile(map_handle,access_mode,high_offset,low_offset,
+        length);
+      CloseHandle(map_handle);
     }
   if (map == (void *) NULL)
     return((void *) MAP_FAILED);
@@ -1707,7 +1714,7 @@ MagickExport MagickBooleanType NTReportEvent(const char *event,
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  NTResourceToBlob() returns a blob containing the contents of the resource
-%  in the current executable specified by the id parameter. This is currently
+%  in the current executable specified by the id parameter. This currently
 %  used to retrieve MGK files tha have been embedded into the various command
 %  line utilities.
 %
