@@ -18,7 +18,7 @@
 %                                December 1996                                %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -53,6 +53,7 @@
 #include "magick/image-private.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/monitor-private.h"
 #include "magick/quantum.h"
 #include "magick/string_.h"
 #include "magick/token.h"
@@ -83,7 +84,7 @@
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o geometry: Define the region of the image to crop with members
 %      x, y, width, and height.
@@ -100,7 +101,7 @@ MagickExport void *CropImageToHBITMAP(Image *image,
     y;
 
   MagickBooleanType
-    status;
+    proceed;
 
   RectangleInfo
     page;
@@ -167,8 +168,8 @@ MagickExport void *CropImageToHBITMAP(Image *image,
   bitmap.bmBitsPixel    = 32;
   bitmap.bmBits         = NULL;
 
-  bitmap_bitsH = (HANDLE) GlobalAlloc (GMEM_MOVEABLE | GMEM_DDESHARE,
-               page.width*page.height*bitmap.bmBitsPixel);
+  bitmap_bitsH=(HANDLE) GlobalAlloc(GMEM_MOVEABLE | GMEM_DDESHARE,page.width*
+    page.height*bitmap.bmBitsPixel);
   if (bitmap_bitsH == NULL)
     return(NULL);
   bitmap_bits=(RGBQUAD *) GlobalLock((HGLOBAL) bitmap_bitsH);
@@ -186,8 +187,8 @@ MagickExport void *CropImageToHBITMAP(Image *image,
     if (p == (const PixelPacket *) NULL)
       break;
 
-#if QuantumDepth == 8
-      /* Form of PixelPacket is identical to RGBQUAD when QuantumDepth==8 */
+#if MAGICKCORE_QUANTUM_DEPTH == 8
+      /* Form of PixelPacket is identical to RGBQUAD when MAGICKCORE_QUANTUM_DEPTH==8 */
       CopyMagickMemory((void*)q,(const void*)p,page.width*sizeof(PixelPacket));
       q += page.width;
 
@@ -208,14 +209,9 @@ MagickExport void *CropImageToHBITMAP(Image *image,
           }
       }
 #endif
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,page.height) != MagickFalse))
-      {
-        status=image->progress_monitor(CropImageTag,y,page.height,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    proceed=SetImageProgress(image,CropImageTag,y,page.height);
+    if (proceed == MagickFalse)
+      break;
   }
   if (y < (long) page.height)
     {
@@ -223,9 +219,10 @@ MagickExport void *CropImageToHBITMAP(Image *image,
       GlobalFree((HGLOBAL) bitmap_bitsH);
       return((void *) NULL);
     }
-  bitmap.bmBits = bitmap_bits;
-  bitmapH = CreateBitmapIndirect( &bitmap );
+  bitmap.bmBits=bitmap_bits;
+  bitmapH=CreateBitmapIndirect(&bitmap);
   GlobalUnlock((HGLOBAL) bitmap_bitsH);
+  GlobalFree((HGLOBAL) bitmap_bitsH);
   return((void *) bitmapH);
 }
 
@@ -254,10 +251,15 @@ MagickExport void *CropImageToHBITMAP(Image *image,
 */
 MagickExport MagickBooleanType NTIsMagickConflict(const char *magick)
 {
+  MagickBooleanType
+    status;
+
   assert(magick != (char *) NULL);
   if (strlen(magick) > 1)
     return(MagickFalse);
-  return((GetLogicalDrives() & (1 << ((toupper((int) (*magick)))-'A'))) != 0);
+  status=(GetLogicalDrives() & (1 << ((toupper((int) (*magick)))-'A'))) != 0 ?
+    MagickTrue : MagickFalse;
+  return(status);
 }
 
 /*
@@ -380,10 +382,9 @@ MagickExport MagickBooleanType NTLoadTypeLists(SplayTreeInfo *type_list,
           continue;
         *pos='\0'; /* Remove (TrueType) from string */
 
-        type_info=(TypeInfo *) AcquireMagickMemory(sizeof(TypeInfo));
+        type_info=(TypeInfo *) AcquireMagickMemory(sizeof(*type_info));
         if (type_info == (TypeInfo *) NULL)
-          ThrowMagickFatalException(ResourceLimitFatalError,
-            "UnableToAllocateTypeInfo",value_name);
+          ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
         (void) ResetMagickMemory(type_info,0,sizeof(TypeInfo));
 
         type_info->path=ConstantString("Windows Fonts");
@@ -429,7 +430,7 @@ MagickExport MagickBooleanType NTLoadTypeLists(SplayTreeInfo *type_list,
 
         for (q=value_name; *q != '\0'; )
           {
-            GetMagickToken(q,&q,token);
+            GetMagickToken(q,(const char **) &q,token);
             if (*token == '\0')
               break;
 
