@@ -61,6 +61,7 @@
 #include "magick/montage.h"
 #include "magick/option.h"
 #include "magick/property.h"
+#include "magick/quantize.h"
 #include "magick/quantum.h"
 #include "magick/resource_.h"
 #include "magick/splay-tree.h"
@@ -270,7 +271,7 @@ static const OptionInfo
     { "+distort", 2L, MagickFalse },
     { "-distort", 2L, MagickFalse },
     { "+dither", 0L, MagickFalse },
-    { "-dither", 0L, MagickFalse },
+    { "-dither", 1L, MagickFalse },
     { "+draw", 0L, MagickFalse },
     { "-draw", 1L, MagickFalse },
     { "+edge", 0L, MagickFalse },
@@ -377,6 +378,8 @@ static const OptionInfo
     { "-log", 1L, MagickFalse },
     { "+loop", 0L, MagickFalse },
     { "-loop", 1L, MagickFalse },
+    { "+lowlight-color", 1L, MagickFalse },
+    { "-lowlight-color", 1L, MagickFalse },
     { "+magnify", 0L, MagickFalse },
     { "-magnify", 1L, MagickFalse },
     { "+map", 0L, MagickFalse },
@@ -786,12 +789,21 @@ static const OptionInfo
     { "Perspective", (long) PerspectiveDistortion, MagickFalse },
     { "PerspectiveProjection", (long) PerspectiveProjectionDistortion, MagickFalse },
     { "Bilinear", (long) BilinearDistortion, MagickFalse },
-    { "Polynomial", (long) PolynomialDistortion, MagickFalse },
+    { "Polynomial", (long) PolynomialDistortion, MagickTrue }, /* not ready */
     { "Arc", (long) ArcDistortion, MagickFalse },
+    { "Polar", (long) PolarDistortion, MagickFalse },
+    { "DePolar", (long) DePolarDistortion, MagickFalse },
     { "Barrel", (long) BarrelDistortion, MagickFalse },
     { "Shepards", (long) ShepardsDistortion, MagickFalse },
     { (char *) NULL, (long) UndefinedDistortion, MagickFalse }
   },
+  DitherOptions[] =
+  {
+    { "Undefined", (long) UndefinedDitherMethod, MagickTrue },
+    { "FloydSteinberg", (long) FloydSteinbergDitherMethod, MagickFalse },
+    { "Riemersma", (long) RiemersmaDitherMethod, MagickFalse },
+    { (char *) NULL, (long) UndefinedEndian, MagickFalse }
+  },
   EndianOptions[] =
   {
     { "Undefined", (long) UndefinedEndian, MagickTrue },
@@ -956,6 +968,7 @@ static const OptionInfo
     { "Decoration", (long) MagickDecorateOptions, MagickFalse },
     { "Dispose", (long) MagickDisposeOptions, MagickFalse },
     { "Distort", (long) MagickDistortOptions, MagickFalse },
+    { "Dither", (long) MagickDitherOptions, MagickFalse },
     { "Endian", (long) MagickEndianOptions, MagickFalse },
     { "Evaluate", (long) MagickEvaluateOptions, MagickFalse },
     { "FillRule", (long) MagickFillRuleOptions, MagickFalse },
@@ -1194,6 +1207,7 @@ static const OptionInfo
     { "Polynomial", (long) PolynomialColorInterpolate, MagickFalse },
     { "Shepards", (long) ShepardsColorInterpolate, MagickFalse },
     { "Voronoi", (long) VoronoiColorInterpolate, MagickFalse },
+    { (char *) NULL, (long) UndefinedResource, MagickFalse }
   },
   StorageOptions[] =
   {
@@ -1252,14 +1266,16 @@ static const OptionInfo
     { "Undefined", (long) UndefinedVirtualPixelMethod, MagickTrue },
     { "Background", (long) BackgroundVirtualPixelMethod, MagickFalse },
     { "Black", (long) BlackVirtualPixelMethod, MagickFalse },
-    { "Constant", (long) BackgroundVirtualPixelMethod, MagickFalse },
+    { "Constant", (long) BackgroundVirtualPixelMethod, MagickTrue }, /* depreciated */
     { "Dither", (long) DitherVirtualPixelMethod, MagickFalse },
     { "Edge", (long) EdgeVirtualPixelMethod, MagickFalse },
     { "Gray", (long) GrayVirtualPixelMethod, MagickFalse },
+    { "HorizontalTile", (long) HorizontalTileVirtualPixelMethod, MagickFalse },
     { "Mirror", (long) MirrorVirtualPixelMethod, MagickFalse },
     { "Random", (long) RandomVirtualPixelMethod, MagickFalse },
     { "Tile", (long) TileVirtualPixelMethod, MagickFalse },
     { "Transparent", (long) TransparentVirtualPixelMethod, MagickFalse },
+    { "VerticalTile", (long) VerticalTileVirtualPixelMethod, MagickFalse },
     { "White", (long) WhiteVirtualPixelMethod, MagickFalse },
     { (char *) NULL, (long) UndefinedVirtualPixelMethod, MagickFalse }
   };
@@ -1509,6 +1525,7 @@ static const OptionInfo *GetOptionInfo(const MagickOption option)
     case MagickDecorateOptions: return(DecorateOptions);
     case MagickDisposeOptions: return(DisposeOptions);
     case MagickDistortOptions: return(DistortOptions);
+    case MagickDitherOptions: return(DitherOptions);
     case MagickEndianOptions: return(EndianOptions);
     case MagickEvaluateOptions: return(EvaluateOptions);
     case MagickFillRuleOptions: return(FillRuleOptions);
@@ -2146,6 +2163,10 @@ MagickExport MagickBooleanType SyncImageOptions(const ImageInfo *image_info,
       if ((flags & SigmaValue) != 0)
         image->ticks_per_second=(long) (geometry_info.sigma+0.5);
     }
+  option=GetImageOption(image_info,"compose");
+  if (option != (const char *) NULL)
+    image->compose=(CompositeOperator) ParseMagickOption(MagickComposeOptions,
+      MagickFalse,option);
   option=GetImageOption(image_info,"dispose");
   if (option != (const char *) NULL)
     image->dispose=(DisposeType) ParseMagickOption(MagickDisposeOptions,
