@@ -401,7 +401,8 @@ static unsigned long **AcquireHistogramThreadSet(const size_t count)
     sizeof(*histogram));
   for (i=0; i < (long) GetCacheViewMaximumThreads(); i++)
   {
-    histogram[i]=AcquireQuantumMemory(count,sizeof(**histogram));
+    histogram[i]=(unsigned long *) AcquireQuantumMemory(count,
+      sizeof(**histogram));
     if (histogram[i] == (unsigned long *) NULL)
       return(DestroyHistogramThreadSet(histogram));
   }
@@ -418,6 +419,7 @@ MagickExport Image *OilPaintImage(const Image *image,const double radius,
     *paint_image;
 
   long
+    progress,
     y;
 
   MagickBooleanType
@@ -459,9 +461,10 @@ MagickExport Image *OilPaintImage(const Image *image,const double radius,
       ThrowImageException(ResourceLimitError,"MemoryAllocationFailed");
     }
   /*
-    Paint each row of the image.
+    Oil paint image.
   */
   status=MagickTrue;
+  progress=0;
   image_view=AcquireCacheViewThreadSet(image);
   paint_view=AcquireCacheViewThreadSet(paint_image);
   #pragma omp parallel for
@@ -538,8 +541,16 @@ MagickExport Image *OilPaintImage(const Image *image,const double radius,
     }
     if (SyncCacheView(paint_view[id]) == MagickFalse)
       status=MagickFalse;
-    if (SetImageProgress(image,OilPaintImageTag,y,image->rows) == MagickFalse)
-      status=MagickFalse;
+    if (image->progress_monitor != (MagickProgressMonitor) NULL)
+      {
+        MagickBooleanType
+          proceed;
+
+        #pragma omp critical
+        proceed=SetImageProgress(image,OilPaintImageTag,progress++,image->rows);
+        if (proceed == MagickFalse)
+          status=MagickFalse;
+      }
   }
   paint_view=DestroyCacheViewThreadSet(paint_view);
   image_view=DestroyCacheViewThreadSet(image_view);
@@ -606,6 +617,7 @@ MagickExport MagickBooleanType OpaquePaintImageChannel(Image *image,
 #define OpaquePaintImageTag  "Opaque/Image"
 
   long
+    progress,
     y;
 
   MagickBooleanType
@@ -614,9 +626,6 @@ MagickExport MagickBooleanType OpaquePaintImageChannel(Image *image,
   ViewInfo
     **image_view;
 
-  /*
-    Make image color opaque.
-  */
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   assert(target != (MagickPixelPacket *) NULL);
@@ -625,14 +634,15 @@ MagickExport MagickBooleanType OpaquePaintImageChannel(Image *image,
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (SetImageStorageClass(image,DirectClass) == MagickFalse)
     return(MagickFalse);
+  /*
+    Make image color opaque.
+  */
   status=MagickTrue;
+  progress=0;
   image_view=AcquireCacheViewThreadSet(image);
   #pragma omp parallel for
   for (y=0; y < (long) image->rows; y++)
   {
-    MagickBooleanType
-      progress;
-
     MagickPixelPacket
       pixel;
 
@@ -678,9 +688,17 @@ MagickExport MagickBooleanType OpaquePaintImageChannel(Image *image,
     }
     if (SyncCacheView(image_view[id]) == MagickFalse)
       status=MagickFalse;
-    progress=SetImageProgress(image,OpaquePaintImageTag,y,image->rows);
-    if (progress == MagickFalse)
-      status=MagickFalse;
+    if (image->progress_monitor != (MagickProgressMonitor) NULL)
+      {
+        MagickBooleanType
+          proceed;
+
+        #pragma omp critical
+        proceed=SetImageProgress(image,OpaquePaintImageTag,progress++,
+          image->rows);
+        if (proceed == MagickFalse)
+          status=MagickFalse;
+      }
   }
   image_view=DestroyCacheViewThreadSet(image_view);
   return(status);
@@ -730,6 +748,7 @@ MagickExport MagickBooleanType TransparentPaintImage(Image *image,
 #define TransparentPaintImageTag  "Transparent/Image"
 
   long
+    progress,
     y;
 
   MagickBooleanType
@@ -738,9 +757,6 @@ MagickExport MagickBooleanType TransparentPaintImage(Image *image,
   ViewInfo
     **image_view;
 
-  /*
-    Make image color transparent.
-  */
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   assert(target != (MagickPixelPacket *) NULL);
@@ -750,14 +766,15 @@ MagickExport MagickBooleanType TransparentPaintImage(Image *image,
     return(MagickFalse);
   if (image->matte == MagickFalse)
     (void) SetImageAlphaChannel(image,ResetAlphaChannel);
+  /*
+    Make image color transparent.
+  */
   status=MagickTrue;
+  progress=0;
   image_view=AcquireCacheViewThreadSet(image);
   #pragma omp parallel for
   for (y=0; y < (long) image->rows; y++)
   {
-    MagickBooleanType
-      progress;
-
     MagickPixelPacket
       pixel;
 
@@ -791,9 +808,17 @@ MagickExport MagickBooleanType TransparentPaintImage(Image *image,
     }
     if (SyncCacheView(image_view[id]) == MagickFalse)
       status=MagickFalse;
-    progress=SetImageProgress(image,TransparentPaintImageTag,y,image->rows);
-    if (progress == MagickFalse)
-      status=MagickFalse;
+    if (image->progress_monitor != (MagickProgressMonitor) NULL)
+      {
+        MagickBooleanType
+          proceed;
+
+        #pragma omp critical
+        proceed=SetImageProgress(image,TransparentPaintImageTag,progress++,
+          image->rows);
+        if (proceed == MagickFalse)
+          status=MagickFalse;
+      }
   }
   image_view=AcquireCacheViewThreadSet(image);
   return(status);
