@@ -1199,6 +1199,152 @@ static void *DestroyProfile(void *profile)
   return((void *) DestroyStringInfo((StringInfo *) profile));
 }
 
+static inline const unsigned char *ReadResourceByte(const unsigned char *p,
+  unsigned char *quantum)
+{
+  *quantum=(*p++);
+  return(p);
+}
+
+static inline const unsigned char *ReadResourceBytes(const unsigned char *p,
+  const ssize_t count,unsigned char *quantum)
+{
+  register ssize_t
+    i;
+
+  for (i=0; i < count; i++)
+    *quantum++=(*p++);
+  return(p);
+}
+
+static inline const unsigned char *ReadResourceLong(const unsigned char *p,
+  unsigned long *quantum)
+{
+  *quantum=(unsigned long) (*p++ << 24);
+  *quantum|=(unsigned long) (*p++ << 16);
+  *quantum|=(unsigned long) (*p++ << 8);
+  *quantum|=(unsigned long) (*p++ << 0);
+  return(p);
+}
+
+static inline const unsigned char *ReadResourceShort(const unsigned char *p,
+  unsigned short *quantum)
+{
+  *quantum=(unsigned short) (*p++ << 8);
+  *quantum|=(unsigned short) (*p++ << 0);
+  return(p);
+}
+
+static MagickBooleanType GetProfilesFromResourceBlock(Image *image,
+  const StringInfo *resource_block)
+{
+  const unsigned char
+    *datum;
+
+  register const unsigned char
+    *p;
+
+  size_t
+    length;
+
+  StringInfo
+    *profile;
+
+  unsigned char
+    length_byte;
+
+  unsigned long
+    count;
+
+  unsigned short
+    id;
+
+  datum=GetStringInfoDatum(resource_block);
+  length=GetStringInfoLength(resource_block);
+  for (p=datum; p < (datum+length-7); )
+  {
+    if (LocaleNCompare((char *) p,"8BIM",4) != 0)
+      break;
+    p+=4;
+    p=ReadResourceShort(p,&id);
+    p=ReadResourceByte(p,&length_byte);
+    p+=length_byte;
+    if (((length_byte+1) & 0x01) != 0)
+      p++;
+    if (p > (datum+length-4))
+      break;
+    p=ReadResourceLong(p,&count);
+    if (p > (datum+length-count))
+      break;
+    switch (id)
+    {
+      case 0x03ed:
+      {
+        unsigned short
+          resolution;
+
+        /*
+          Resolution.
+        */
+        p=ReadResourceShort(p,&resolution)+6;
+        image->x_resolution=(double) resolution;
+        p=ReadResourceShort(p,&resolution)+6;
+        image->y_resolution=(double) resolution;
+        break;
+      }
+      case 0x040c:
+      {
+        /*
+          Thumbnail.
+        */
+        p+=count;
+        break;
+      }
+      case 0x040f:
+      {
+        /*
+          ICC Profile.
+        */
+        profile=AcquireStringInfo(count);
+        SetStringInfoDatum(profile,p);
+        (void) SetImageProfile(image,"icc",profile);
+        p+=count;
+        break;
+      }
+      case 0x0422:
+      {
+        /*
+          EXIF Profile.
+        */
+        profile=AcquireStringInfo(count);
+        SetStringInfoDatum(profile,p);
+        (void) SetImageProfile(image,"exif",profile);
+        p+=count;
+        break;
+      }
+      case 0x0424:
+      {
+        /*
+          XMP Profile.
+        */
+        profile=AcquireStringInfo(count);
+        SetStringInfoDatum(profile,p);
+        (void) SetImageProfile(image,"xmp",profile);
+        p+=count;
+        break;
+      }
+      default:
+      {
+        p+=count;
+        break;
+      }
+    }
+    if ((count & 0x01) != 0)
+      p++;
+  }
+  return(MagickTrue);
+}
+
 MagickExport MagickBooleanType SetImageProfile(Image *image,const char *name,
   const StringInfo *profile)
 {
@@ -1250,6 +1396,7 @@ MagickExport MagickBooleanType SetImageProfile(Image *image,const char *name,
           image->iptc_profile.length=GetStringInfoLength(iptc_profile);
           image->iptc_profile.info=GetStringInfoDatum(iptc_profile);
         }
+      (void) GetProfilesFromResourceBlock(image,profile);
     }
   /*
     Inject profile into image properties.
