@@ -1390,14 +1390,17 @@ static MagickBooleanType GetXMPProperty(const Image *image,
   MagickBooleanType
     status;
 
+  register const char
+    *p;
+
   register long
     i;
 
-  register unsigned char
-    *p;
-
   XMLTreeInfo
     *child,
+    *description,
+    *node,
+    *rdf,
     *xmp;
 
   profile=GetImageProfile(image,"xmp");
@@ -1405,29 +1408,48 @@ static MagickBooleanType GetXMPProperty(const Image *image,
     return(MagickFalse);
   if ((property == (const char *) NULL) || (*property == '\0'))
     return(MagickFalse);
-  p=GetStringInfoDatum(profile);
-  for (i=0; (i < (long) GetStringInfoLength(profile)) && (*p != '\0'); i++)
-    p++;
-  if (i == (long) GetStringInfoLength(profile))
-    return(MagickFalse);
   exception=AcquireExceptionInfo();
-  xmp=NewXMLTree((char *) ++p,exception);
+  p=(const char *) GetStringInfoDatum(profile);
+  for (i=0; i < (long) (GetStringInfoLength(profile)-1); i++)
+  {
+    if ((*p == '<') && (*(p+1) == 'x'))
+      break;
+    p++;
+  }
+  xmp=NewXMLTree((char *) p,exception);
   exception=DestroyExceptionInfo(exception);
   if (xmp == (XMLTreeInfo *) NULL)
     return(MagickFalse);
   status=MagickFalse;
-  child=GetXMLTreeChild(xmp,"rdf:RDF");
-  if (child != (XMLTreeInfo *) NULL)
+  rdf=GetXMLTreeChild(xmp,"rdf:RDF");
+  if (rdf != (XMLTreeInfo *) NULL)
     {
-      child=GetXMLTreeChild(child,"rdf:Description");
-      if (child != (XMLTreeInfo *) NULL)
+      if (image->properties == (void *) NULL)
+        ((Image *) image)->properties=NewSplayTree(CompareSplayTreeString,
+          RelinquishMagickMemory,RelinquishMagickMemory);
+      description=GetXMLTreeChild(rdf,"rdf:Description");
+      while (description != (XMLTreeInfo *) NULL)
+      {
+        node=GetXMLTreeChild(description,(const char *) NULL);
+        while (node != (XMLTreeInfo *) NULL)
         {
-          if (image->properties == (void *) NULL)
-            ((Image *) image)->properties=NewSplayTree(CompareSplayTreeString,
-              RelinquishMagickMemory,RelinquishMagickMemory);
-          status=GetXMLTreeAttributes(child,(SplayTreeInfo *)
-            image->properties);
+          child=GetXMLTreeChild(node,(const char *) NULL);
+          if (child == (XMLTreeInfo *) NULL)
+            (void) AddValueToSplayTree((SplayTreeInfo *) image->properties,
+              ConstantString(GetXMLTreeTag(node)),
+              ConstantString(GetXMLTreeContent(node)));
+          while (child != (XMLTreeInfo *) NULL)
+          {
+            if (LocaleCompare(GetXMLTreeTag(child),"rdf:Seq") != 0)
+              (void) AddValueToSplayTree((SplayTreeInfo *) image->properties,
+                ConstantString(GetXMLTreeTag(child)),
+                ConstantString(GetXMLTreeContent(child)));
+            child=GetXMLTreeSibling(child);
+          }
+          node=GetXMLTreeSibling(node);
         }
+        description=GetNextXMLTreeTag(description);
+      }
     }
   xmp=DestroyXMLTree(xmp);
   return(status);
@@ -2230,7 +2252,8 @@ static const char *GetMagickProperty(const ImageInfo *image_info,Image *image,
             (unsigned long) GetImageListLength(image));
           break;
         }
-      if (LocaleNCompare("standard-deviation",property,18) == 0)
+      if ((LocaleNCompare("standard-deviation",property,18) == 0) ||
+          (LocaleNCompare("standard_deviation",property,18) == 0))
         {
           double
             mean,
@@ -2719,6 +2742,15 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
         q+=FormatMagickString(q,extent,"%+ld",image->page.y);
         break;
       }
+      case 'Z':
+      {
+        /*
+          Unique filename.
+        */
+        (void) CopyMagickString(filename,text_info->zero,extent);
+        q+=CopyMagickString(q,filename,extent);
+        break;
+      }
       case '[':
       {
         char
