@@ -24,6 +24,13 @@ extern "C" {
 
 #include "magick/colorspace.h"
 
+typedef enum
+{
+  UndefinedDitherMethod,
+  RiemersmaDitherMethod,
+  FloydSteinbergDitherMethod
+} DitherMethod;
+
 typedef struct _QuantizeInfo
 {
   unsigned long
@@ -43,6 +50,9 @@ typedef struct _QuantizeInfo
 
   unsigned long
     signature;
+
+  DitherMethod
+    dither_method;
 } QuantizeInfo;
 
 extern MagickExport MagickBooleanType
