@@ -614,29 +614,29 @@ MagickExport size_t ExportQuantumPixels(Image *image,
           for (x=((long) number_pixels-7); x > 0; x-=8)
           {
             *q='\0';
-            *q|=(PixelIntensityToQuantum(p) < (QuantumRange/2) ? black :
-              white) << 7;
+            *q|=(PixelIntensityToQuantum(p) < (Quantum) (QuantumRange/2) ?
+              black : white) << 7;
             p++;
-            *q|=(PixelIntensityToQuantum(p) < (QuantumRange/2) ? black :
-              white) << 6;
+            *q|=(PixelIntensityToQuantum(p) < (Quantum) (QuantumRange/2) ?
+              black : white) << 6;
             p++;
-            *q|=(PixelIntensityToQuantum(p) < (QuantumRange/2) ? black :
-              white) << 5;
+            *q|=(PixelIntensityToQuantum(p) < (Quantum) (QuantumRange/2) ?
+              black : white) << 5;
             p++;
-            *q|=(PixelIntensityToQuantum(p) < (QuantumRange/2) ? black :
-              white) << 4;
+            *q|=(PixelIntensityToQuantum(p) < (Quantum) (QuantumRange/2) ?
+              black : white) << 4;
             p++;
-            *q|=(PixelIntensityToQuantum(p) < (QuantumRange/2) ? black :
-              white) << 3;
+            *q|=(PixelIntensityToQuantum(p) < (Quantum) (QuantumRange/2) ?
+              black : white) << 3;
             p++;
-            *q|=(PixelIntensityToQuantum(p) < (QuantumRange/2) ? black :
-              white) << 2;
+            *q|=(PixelIntensityToQuantum(p) < (Quantum) (QuantumRange/2) ?
+              black : white) << 2;
             p++;
-            *q|=(PixelIntensityToQuantum(p) < (QuantumRange/2) ? black :
-              white) << 1;
+            *q|=(PixelIntensityToQuantum(p) < (Quantum) (QuantumRange/2) ?
+              black : white) << 1;
             p++;
-            *q|=(PixelIntensityToQuantum(p) < (QuantumRange/2) ? black :
-              white) << 0;
+            *q|=(PixelIntensityToQuantum(p) < (Quantum) (QuantumRange/2) ?
+              black : white) << 0;
             p++;
             q++;
           }
@@ -645,8 +645,8 @@ MagickExport size_t ExportQuantumPixels(Image *image,
               *q='\0';
               for (bit=7; bit >= (long) (8-(number_pixels % 8)); bit--)
               {
-                *q|=(PixelIntensityToQuantum(p) < (QuantumRange/2) ? black :
-                  white) << bit;
+                *q|=(PixelIntensityToQuantum(p) < (Quantum) (QuantumRange/2) ?
+                  black : white) << bit;
                 p++;
               }
               q++;
