@@ -838,7 +838,7 @@ MagickExport MagickPixelPacket ResamplePixelColor(
 
   /*
     Does resample area Miss the image?
-    And area is in virtual areas of solid color - return that color
+    And is that area a simple solid color - then return that color
   */
   hit = 0;
   switch ( resample_filter->virtual_pixel ) {
@@ -870,7 +870,18 @@ MagickExport MagickPixelPacket ResamplePixelColor(
            )
         hit++;
       break;
-
+    case HorizontalTileVirtualPixelMethod:
+      if (    v0 + resample_filter->sqrtA < 0.0
+           || v0 - resample_filter->sqrtA > (double) resample_filter->image->rows
+           )
+        hit++;  /* outside the horizontally tiled images. */
+      break;
+    case VerticalTileVirtualPixelMethod:
+      if (    u0 + resample_filter->sqrtC < 0.0
+           || u0 - resample_filter->sqrtC > (double) resample_filter->image->columns
+           )
+        hit++;  /* outside the vertically tiled images. */
+      break;
     case DitherVirtualPixelMethod:
       if (    ( u0 + resample_filter->sqrtC < -32.0 && v0 + resample_filter->sqrtA < -32.0 )
            || ( u0 + resample_filter->sqrtC < -32.0
@@ -885,7 +896,7 @@ MagickExport MagickPixelPacket ResamplePixelColor(
     case TileVirtualPixelMethod:
     case MirrorVirtualPixelMethod:
     case RandomVirtualPixelMethod:
-      /* resampling of arealways needed - no VP limits */
+      /* resampling of area is always needed - no VP limits */
       break;
   }
   if ( hit ) {
@@ -895,7 +906,7 @@ MagickExport MagickPixelPacket ResamplePixelColor(
   }
 
   /*
-    Scaling limits reached, return 'averaged' result.
+    Scaling limits reached, return an 'averaged' result.
   */
   if ( resample_filter->limit_reached ) {
     switch ( resample_filter->virtual_pixel ) {
@@ -1362,7 +1373,7 @@ static void SetResampleFilter(ResampleFilter *resample_filter,
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   S e t R e s a m p l e F i l t e r I n t e r p o l a t e M e t h o d        %
+%   S e t R e s a m p l e F i l t e r I n t e r p o l a t e M e t h o d       %
 %                                                                             %
 %                                                                             %
 %                                                                             %
