@@ -704,9 +704,9 @@ MagickExport MagickBooleanType GetImageChannelRange(const Image *image,
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  GetImageChannelStatistics() returns statistics for each channel in the
-%  image.  The statistics incude the channel depth, its minimand
-%  maxima, the mean, and the standard deviation.  You can access the red
-%  channel mean, for example, like this:
+%  image.  The statistics incude the channel depth, its minima, maxima, mean,
+%  and the standard deviation.  You can access the red channel mean, for
+%  example, like this:
 %
 %      channel_statistics=GetImageChannelStatistics(image,excepton);
 %      red_mean=channel_statistics[RedChannel].mean;
@@ -784,7 +784,8 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
     sizeof(*channel_statistics));
   if (channel_statistics == (ChannelStatistics *) NULL)
     ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
-  (void) ResetMagickMemory(channel_statistics,0,length);
+  (void) ResetMagickMemory(channel_statistics,0,length*
+    sizeof(*channel_statistics));
   for (i=0; i <= AllChannels; i++)
   {
     channel_statistics[i].depth=1;
