@@ -63,6 +63,7 @@
 #include "magick/log.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/monitor-private.h"
 #include "magick/montage.h"
 #include "magick/pixel-private.h"
 #include "magick/quantize.h"
@@ -153,7 +154,7 @@ MagickExport Image *AdaptiveThresholdImage(const Image *image,
     y;
 
   MagickBooleanType
-    status;
+    proceed;
 
   MagickPixelPacket
     pixel,
@@ -245,14 +246,9 @@ MagickExport Image *AdaptiveThresholdImage(const Image *image,
     }
     if (SyncImagePixels(threshold_image) == MagickFalse)
       break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(ThresholdImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    proceed=SetImageProgress(image,ThresholdImageTag,y,image->rows);
+    if (proceed == MagickFalse)
+      break;
   }
   return(threshold_image);
 }
@@ -319,7 +315,7 @@ MagickExport MagickBooleanType BilevelImageChannel(Image *image,
     y;
 
   MagickBooleanType
-    status;
+    proceed;
 
   register IndexPacket
     *indexes;
@@ -385,14 +381,9 @@ MagickExport MagickBooleanType BilevelImageChannel(Image *image,
       }
     if (SyncImagePixels(image) == MagickFalse)
       break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(ThresholdImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    proceed=SetImageProgress(image,ThresholdImageTag,y,image->rows);
+    if (proceed == MagickFalse)
+      break;
   }
   return(MagickTrue);
 }
@@ -435,7 +426,7 @@ MagickExport MagickBooleanType BlackThresholdImage(Image *image,
     y;
 
   MagickBooleanType
-    status;
+    proceed;
 
   MagickPixelPacket
     pixel;
@@ -510,14 +501,9 @@ MagickExport MagickBooleanType BlackThresholdImage(Image *image,
       }
     if (SyncImagePixels(image) == MagickFalse)
       break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(ThresholdImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    proceed=SetImageProgress(image,ThresholdImageTag,y,image->rows);
+    if (proceed == MagickFalse)
+      break;
   }
   return(MagickTrue);
 }
@@ -1053,12 +1039,13 @@ MagickExport MagickBooleanType OrderedPosterizeImageChannel(Image *image,
   const ChannelType channel,const char *threshold_map,ExceptionInfo *exception)
 {
 #define DitherImageTag  "Dither/Image"
-  ThresholdMap
-    *map;
 
   LongPixelPacket
     levels;
 
+  MagickBooleanType
+    proceed;
+
   long
     y;
 
@@ -1068,6 +1055,9 @@ MagickExport MagickBooleanType OrderedPosterizeImageChannel(Image *image,
   register IndexPacket
     *indexes;
 
+  ThresholdMap
+    *map;
+
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
@@ -1235,15 +1225,9 @@ printf("DEBUG levels  r=%ld g=%ld b=%ld a=%ld i=%ld\n",
       }
       if (SyncImagePixels(image) == MagickFalse)
         break;
-      if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-          (QuantumTick(y,image->rows) != MagickFalse))
-        {
-          MagickBooleanType
-            status=image->progress_monitor(DitherImageTag,y,image->rows,
-               image->client_data);
-          if (status == MagickFalse)
-            break;
-        }
+      proceed=SetImageProgress(image,DitherImageTag,y,image->rows);
+      if (proceed == MagickFalse)
+        break;
     }
   }
   map=DestroyThresholdMap(map);
@@ -1313,6 +1297,7 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
     y;
 
   MagickBooleanType
+    proceed,
     status;
 
   MagickPixelPacket
@@ -1387,21 +1372,17 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
           else if (intensity > max_threshold)
             threshold.index=max_threshold;
           else
-            threshold.index=(MagickRealType)(QuantumRange*GetPseudoRandomValue());
+            threshold.index=(MagickRealType)(QuantumRange*
+              GetPseudoRandomValue());
           index=(IndexPacket) (intensity <= threshold.index ? 0 : 1);
           indexes[x]=index;
           *q++=image->colormap[(long) index];
         }
         if (SyncImagePixels(image) == MagickFalse)
           break;
-        if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-            (QuantumTick(y,image->rows) != MagickFalse))
-          {
-            status=image->progress_monitor(ThresholdImageTag,y,image->rows,
-              image->client_data);
-            if (status == MagickFalse)
-              break;
-          }
+        proceed=SetImageProgress(image,ThresholdImageTag,y,image->rows);
+        if (proceed == MagickFalse)
+          break;
       }
       return(MagickTrue);
     }
@@ -1494,14 +1475,9 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
     }
     if (SyncImagePixels(image) == MagickFalse)
       break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(ThresholdImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    proceed=SetImageProgress(image,ThresholdImageTag,y,image->rows);
+    if (proceed == MagickFalse)
+      break;
   }
   return(MagickTrue);
 }
@@ -1544,7 +1520,7 @@ MagickExport MagickBooleanType WhiteThresholdImage(Image *image,
     y;
 
   MagickBooleanType
-    status;
+    proceed;
 
   MagickPixelPacket
     pixel;
@@ -1619,14 +1595,9 @@ MagickExport MagickBooleanType WhiteThresholdImage(Image *image,
       }
     if (SyncImagePixels(image) == MagickFalse)
       break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(ThresholdImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    proceed=SetImageProgress(image,ThresholdImageTag,y,image->rows);
+    if (proceed == MagickFalse)
+      break;
   }
   return(MagickTrue);
 }
