@@ -53,6 +53,7 @@
 #include "magick/layer.h"
 #include "magick/list.h"
 #include "magick/monitor.h"
+#include "magick/monitor-private.h"
 #include "magick/pixel-private.h"
 #include "magick/resource_.h"
 #include "magick/resize.h"
@@ -101,7 +102,7 @@ MagickExport Image *ChopImage(const Image *image,const RectangleInfo *chop_info,
     y;
 
   MagickBooleanType
-    status;
+    proceed;
 
   RectangleInfo
     extent;
@@ -184,14 +185,9 @@ MagickExport Image *ChopImage(const Image *image,const RectangleInfo *chop_info,
     }
     if (SyncImagePixels(chop_image) == MagickFalse)
       break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(j,chop_image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(ChopImageTag,j,chop_image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    proceed=SetImageProgress(image,ChopImageTag,y,chop_image->rows);
+    if (proceed == MagickFalse)
+      break;
   }
   /*
     Extract chop image.
@@ -219,14 +215,9 @@ MagickExport Image *ChopImage(const Image *image,const RectangleInfo *chop_info,
     }
     if (SyncImagePixels(chop_image) == MagickFalse)
       break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(j,chop_image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(ChopImageTag,j,chop_image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    proceed=SetImageProgress(image,ChopImageTag,y,chop_image->rows);
+    if (proceed == MagickFalse)
+      break;
   }
   chop_image->type=image->type;
   return(chop_image);
@@ -417,7 +408,7 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
     y;
 
   MagickBooleanType
-    status;
+    proceed;
 
   RectangleInfo
     bounding_box,
@@ -555,14 +546,9 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
         sizeof(*crop_indexes));
     if (SyncCacheView(crop_view) == MagickFalse)
       break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(CropImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    proceed=SetImageProgress(image,CropImageTag,y,image->rows);
+    if (proceed == MagickFalse)
+      break;
   }
   crop_view=DestroyCacheView(crop_view);
   image_view=DestroyCacheView(image_view);
@@ -610,7 +596,7 @@ MagickExport Image *ExcerptImage(const Image *image,
     y;
 
   MagickBooleanType
-    status;
+    proceed;
 
   register IndexPacket
     *excerpt_indexes,
@@ -655,14 +641,9 @@ MagickExport Image *ExcerptImage(const Image *image,
         excerpt_image->columns*sizeof(*excerpt_indexes));
     if (SyncImagePixels(excerpt_image) == MagickFalse)
       break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,excerpt_image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(ExcerptImageTag,y,excerpt_image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    proceed=SetImageProgress(image,ExcerptImageTag,y,excerpt_image->rows);
+    if (proceed == MagickFalse)
+      break;
   }
   return(excerpt_image);
 }
@@ -767,7 +748,7 @@ MagickExport Image *FlipImage(const Image *image,ExceptionInfo *exception)
     y;
 
   MagickBooleanType
-    status;
+    proceed;
 
   register const PixelPacket
     *p;
@@ -810,14 +791,9 @@ MagickExport Image *FlipImage(const Image *image,ExceptionInfo *exception)
         sizeof(*flip_indexes));
     if (SyncImagePixels(flip_image) == MagickFalse)
       break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,flip_image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(FlipImageTag,y,flip_image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    proceed=SetImageProgress(image,FlipImageTag,y,flip_image->rows);
+    if (proceed == MagickFalse)
+      break;
   }
   flip_image->type=image->type;
   return(flip_image);
@@ -859,7 +835,7 @@ MagickExport Image *FlopImage(const Image *image,ExceptionInfo *exception)
     y;
 
   MagickBooleanType
-    status;
+    proceed;
 
   register IndexPacket
     *flop_indexes,
@@ -909,14 +885,9 @@ MagickExport Image *FlopImage(const Image *image,ExceptionInfo *exception)
     }
     if (SyncImagePixels(flop_image) == MagickFalse)
       break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,flop_image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(FlopImageTag,y,flop_image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    proceed=SetImageProgress(image,FlopImageTag,y,flop_image->rows);
+    if (proceed == MagickFalse)
+      break;
   }
   flop_image->type=image->type;
   return(flop_image);
@@ -963,7 +934,7 @@ MagickExport Image *RollImage(const Image *image,const long x_offset,
     y;
 
   MagickBooleanType
-    status;
+    proceed;
 
   register const PixelPacket
     *p;
@@ -1030,14 +1001,9 @@ MagickExport Image *RollImage(const Image *image,const long x_offset,
         break;
       p++;
     }
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(RollImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    proceed=SetImageProgress(image,RollImageTag,y,image->rows);
+    if (proceed == MagickFalse)
+      break;
   }
   roll_image->type=image->type;
   return(roll_image);
@@ -1149,7 +1115,7 @@ MagickExport Image *SpliceImage(const Image *image,
     y;
 
   MagickBooleanType
-    status;
+    proceed;
 
   RectangleInfo
     splice_geometry;
@@ -1278,14 +1244,9 @@ MagickExport Image *SpliceImage(const Image *image,
     }
     if (SyncImagePixels(splice_image) == MagickFalse)
       break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,splice_image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(SpliceImageTag,y,splice_image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    proceed=SetImageProgress(image,SpliceImageTag,y,splice_image->rows);
+    if (proceed == MagickFalse)
+      break;
   }
   for ( ; y < (long) (splice_geometry.y+splice_geometry.height); y++)
   {
@@ -1301,14 +1262,9 @@ MagickExport Image *SpliceImage(const Image *image,
     }
     if (SyncImagePixels(splice_image) == MagickFalse)
       break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,splice_image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(SpliceImageTag,y,splice_image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    proceed=SetImageProgress(image,SpliceImageTag,y,splice_image->rows);
+    if (proceed == MagickFalse)
+      break;
   }
   for ( ; y < (long) splice_image->rows; y++)
   {
@@ -1338,14 +1294,9 @@ MagickExport Image *SpliceImage(const Image *image,
     }
     if (SyncImagePixels(splice_image) == MagickFalse)
       break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,splice_image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(SpliceImageTag,y,splice_image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    proceed=SetImageProgress(image,SpliceImageTag,y,splice_image->rows);
+    if (proceed == MagickFalse)
+      break;
   }
   return(splice_image);
 }
@@ -1597,7 +1548,7 @@ MagickExport Image *TransposeImage(const Image *image,ExceptionInfo *exception)
     y;
 
   MagickBooleanType
-    status;
+    proceed;
 
   RectangleInfo
     page;
@@ -1642,14 +1593,9 @@ MagickExport Image *TransposeImage(const Image *image,ExceptionInfo *exception)
         image->columns*sizeof(*transpose_indexes));
     if (SyncImagePixels(transpose_image) == MagickFalse)
       break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(TransposeImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    proceed=SetImageProgress(image,TransposeImageTag,y,image->rows);
+    if (proceed == MagickFalse)
+      break;
   }
   page=transpose_image->page;
   Swap(page.width,page.height);
