@@ -99,7 +99,7 @@ int main ( int argc, char **argv )
               (void) SetLogEventMask(argv[++arg]);
           else if (LocaleCompare("depth",option+1) == 0)
             {
-              imageInfo->depth=QuantumDepth;
+              imageInfo->depth=MAGICKCORE_QUANTUM_DEPTH;
               arg++;
               if ((arg == argc) || !sscanf(argv[arg],"%ld",&imageInfo->depth))
                 {
@@ -205,8 +205,7 @@ if (0)
     "Writing image %s", original->filename);
   WriteImage ( imageInfo, original );
   imageInfo->depth=original->depth;
-   original =DestroyImage( original );
-  original = (Image*)NULL;
+  original=DestroyImageList(original);
 
   /*
    * Read image back from file
@@ -273,7 +272,7 @@ if (0)
    */
 
   fuzz_factor = 0.0;
-#if defined(UseHDRI)
+#if defined(MAGICKCORE_HDRI_SUPPORT)
   fuzz_factor = 0.06;
 #endif
   if ( !strcmp( "JPEG", format ) ||
@@ -286,10 +285,16 @@ if (0)
        !strcmp( "CMYK", format ) ||
        !strcmp( "PCD", format ) ||
        !strcmp( "PCDS", format ) ||
+       !strcmp( "PGM", format ) ||
+       !strcmp( "PPM", format ) ||
+       !strcmp( "PNM", format ) ||
+       !strcmp( "SGI", format ) ||
+       !strcmp( "XPM", format ) ||
        !strcmp( "UYVY", format ) ||
        !strcmp( "YUV", format ) || (final->compression == JPEGCompression))
     fuzz_factor = 0.06;
 
+  SetImageColorspace(final,original->colorspace);
   if ( !IsImagesEqual(original, final ) &&
        (original->error.normalized_mean_error > fuzz_factor) )
     {
@@ -304,13 +309,10 @@ if (0)
 
  program_exit:
   if (original)
-     original =DestroyImage( original );
-  original = (Image*)NULL;
+    original=DestroyImageList(original);
   if (final)
-     final =DestroyImage( final );
-  final = (Image*)NULL;
-
-  imageInfo =DestroyImageInfo( imageInfo );
+    final =DestroyImageList(final);
+  imageInfo=DestroyImageInfo(imageInfo);
   DestroyExceptionInfo( &exception );
   MagickCoreTerminus();
 
