@@ -101,7 +101,7 @@ int main(int argc,char **argv)
   MagickCoreGenesis(*argv,MagickTrue);
   exception=AcquireExceptionInfo();
   iterations=1;
-  status=MagickTrue;
+  status=MagickFalse;
   regard_warnings=MagickFalse;
   for (i=1; i < (long) (argc-1); i++)
   {
@@ -120,10 +120,10 @@ int main(int argc,char **argv)
   {
     image_info=AcquireImageInfo();
     status=ConvertImageCommand(image_info,argc,argv,(char **) NULL,exception);
-    if ((status == MagickFalse) || (exception->severity != UndefinedException))
+    if (exception->severity != UndefinedException)
       {
-        if ((exception->severity < ErrorException) &&
-            (regard_warnings == MagickFalse))
+        if ((exception->severity > ErrorException) ||
+            (regard_warnings != MagickFalse))
           status=MagickTrue;
         CatchException(exception);
       }
@@ -139,5 +139,5 @@ int main(int argc,char **argv)
     }
   exception=DestroyExceptionInfo(exception);
   MagickCoreTerminus();
-  return(status == MagickFalse ? 1 : 0);
+  return(status == MagickFalse ? 0 : 1);
 }
