@@ -139,7 +139,7 @@ static void AnimateUsage(void)
       "-depth value         image depth",
       "-display server      display image to this X server",
       "-dispose method      layer disposal method",
-      "-dither              apply Floyd/Steinberg error diffusion to image",
+      "-dither method       apply error diffusion to image",
       "-filter type         use this filter when resizing an image",
       "-format \"string\"     output formatted image characteristics",
       "-gamma value         level of gamma correction",
@@ -775,7 +775,21 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("dither",option+1) == 0)
           {
-            quantize_info->dither=(*option == '-') ? MagickTrue : MagickFalse;
+            long
+              method;
+
+            quantize_info->dither=MagickFalse;
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowAnimateException(OptionError,"MissingArgument",option);
+            method=ParseMagickOption(MagickDitherOptions,MagickFalse,argv[i]);
+            if (method < 0)
+              ThrowAnimateException(OptionError,"UnrecognizedDitherMethod",
+                argv[i]);
+            quantize_info->dither=MagickTrue;
+            quantize_info->dither_method=(DitherMethod) method;
             break;
           }
         ThrowAnimateException(OptionError,"UnrecognizedOption",option);
