@@ -99,6 +99,7 @@ static void CompareUsage(void)
       "                     decipher image with this password",
       "-channel type        apply option to select image channels",
       "-colorspace type     alternate image colorspace",
+      "-compose operator    set image composite operator",
       "-compress type       type of pixel compression when writing the image",
       "-decipher filename   convert cipher pixels to plain pixels",
       "-define format:option",
@@ -110,10 +111,12 @@ static void CompareUsage(void)
       "-format \"string\"     output formatted image characteristics",
       "-fuzz distance       colors within this distance are considered equal",
       "-highlight-color color",
-      "                     highlight pixel differences with this color",
+      "                     empasize pixel differences with this color",
       "-identify            identify the format and characteristics of the image",
       "-interlace type      type of image interlacing scheme",
       "-limit type value    pixel cache resource limit",
+      "-lowlight-color color",
+      "                     de-emphasize pixel differences with this color",
       "-metric type         measure differences between images with this metric",
       "-monitor             monitor progress",
       "-passphrase filename get the passphrase from this file",
@@ -194,7 +197,7 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
     *format;
 
   ChannelType
-    channel;
+    channels;
 
   double
     distortion;
@@ -246,7 +249,7 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
     }
   if (argc < 3)
     CompareUsage();
-  channel=AllChannels;
+  channels=AllChannels;
   difference_image=NewImageList();
   distortion=0.0;
   format=(char *) NULL;
@@ -366,6 +369,7 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
             if (channel < 0)
               ThrowCompareException(OptionError,"UnrecognizedChannelType",
                 argv[i]);
+            channels=(ChannelType) channel;
             break;
           }
         if (LocaleCompare("colorspace",option+1) == 0)
@@ -385,6 +389,23 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
                 argv[i]);
             break;
           }
+        if (LocaleCompare("compose",option+1) == 0)
+          {
+            long
+              compose;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowCompareException(OptionError,"MissingArgument",option);
+            compose=ParseMagickOption(MagickComposeOptions,MagickFalse,
+              argv[i]);
+            if (compose < 0)
+              ThrowCompareException(OptionError,"UnrecognizedComposeOperator",
+                argv[i]);
+            break;
+          }
         if (LocaleCompare("compress",option+1) == 0)
           {
             long
@@ -597,6 +618,15 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
               ThrowCompareException(OptionError,"MissingArgument",option);
             break;
           }
+        if (LocaleCompare("lowlight-color",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowCompareException(OptionError,"MissingArgument",option);
+            break;
+          }
         ThrowCompareException(OptionError,"UnrecognizedOption",option)
       }
       case 'm':
@@ -827,7 +857,7 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
   FireImageStack(MagickTrue,MagickTrue,MagickTrue);
   image=GetImageFromList(image,0);
   reconstruct_image=GetImageFromList(image,1);
-  difference_image=CompareImageChannels(image,reconstruct_image,channel,
+  difference_image=CompareImageChannels(image,reconstruct_image,channels,
     metric,&distortion,exception);
   if (difference_image == (Image *) NULL)
     status=0;
@@ -850,33 +880,171 @@ WandExport MagickBooleanType CompareImageCommand(ImageInfo *image_info,
           text=DestroyString(text);
         }
       difference_image=DestroyImageList(difference_image);
-      switch (metric)
-      {
-        case MeanAbsoluteErrorMetric:
-        case RootMeanSquaredErrorMetric:
-        case PeakAbsoluteErrorMetric:
+      if (image_info->verbose == MagickFalse)
+        switch (metric)
         {
-          (void) fprintf(stderr,"%g (%g)\n",distortion,(double) (QuantumScale*
-            distortion));
-          break;
+          case MeanAbsoluteErrorMetric:
+          case MeanSquaredErrorMetric:
+          case RootMeanSquaredErrorMetric:
+          case PeakAbsoluteErrorMetric:
+          {
+            (void) fprintf(stderr,"%g (%g)\n",distortion,(double) (QuantumScale*
+              distortion));
+            break;
+          }
+          case AbsoluteErrorMetric:
+          case PeakSignalToNoiseRatioMetric:
+          {
+            (void) fprintf(stderr,"%g\n",distortion);
+            break;
+          }
+          case MeanErrorPerPixelMetric:
+          {
+            (void) fprintf(stderr,"%g (%g, %g)\n",distortion,
+              image->error.normalized_mean_error,
+              image->error.normalized_maximum_error);
+            break;
+          }
+          case UndefinedMetric:
+            break;
         }
-        case AbsoluteErrorMetric:
-        case MeanSquaredErrorMetric:
-        case PeakSignalToNoiseRatioMetric:
+      else
         {
-          (void) fprintf(stderr,"%g\n",distortion);
-          break;
+          double
+            *channel_distortion;
+
+ 
+          channel_distortion=GetImageChannelDistortions(image,reconstruct_image,
+            metric,&image->exception);
+          (void) fprintf(stderr,"Image: %s\n",image->filename);
+          (void) fprintf(stderr,"  Channel distortion: %s\n",
+            MagickOptionToMnemonic(MagickMetricOptions,(long) metric));
+          switch (metric)
+          {
+            case MeanAbsoluteErrorMetric:
+            case MeanSquaredErrorMetric:
+            case RootMeanSquaredErrorMetric:
+            case PeakAbsoluteErrorMetric:
+            {
+              switch (image->colorspace)
+              {
+                case RGBColorspace:
+                default:
+                {
+                  (void) fprintf(stderr,"    red: %g (%g)\n",
+                    channel_distortion[RedChannel],(double) QuantumScale*
+                    channel_distortion[RedChannel]);
+                  (void) fprintf(stderr,"    green: %g (%g)\n",
+                    channel_distortion[GreenChannel],(double) QuantumScale*
+                    channel_distortion[GreenChannel]);
+                  (void) fprintf(stderr,"    blue: %g (%g)\n",
+                    channel_distortion[BlueChannel],(double) QuantumScale*
+                    channel_distortion[BlueChannel]);
+                  if (image->matte != MagickFalse)
+                    (void) fprintf(stderr,"    alpha: %g (%g)\n",
+                      channel_distortion[OpacityChannel],(double) QuantumScale*
+                      channel_distortion[OpacityChannel]);
+                  break;
+                }
+                case CMYKColorspace:
+                {
+                  (void) fprintf(stderr,"    cyan: %g (%g)\n",
+                    channel_distortion[CyanChannel],(double) QuantumScale*
+                    channel_distortion[CyanChannel]);
+                  (void) fprintf(stderr,"    magenta: %g (%g)\n",
+                    channel_distortion[MagentaChannel],(double) QuantumScale*
+                    channel_distortion[MagentaChannel]);
+                  (void) fprintf(stderr,"    yellow: %g (%g)\n",
+                    channel_distortion[YellowChannel],(double) QuantumScale*
+                    channel_distortion[YellowChannel]);
+                  (void) fprintf(stderr,"    black: %g (%g)\n",
+                    channel_distortion[BlackChannel],(double) QuantumScale*
+                    channel_distortion[BlackChannel]);
+                  if (image->matte != MagickFalse)
+                    (void) fprintf(stderr,"    alpha: %g (%g)\n",
+                      channel_distortion[OpacityChannel],(double) QuantumScale*
+                      channel_distortion[OpacityChannel]);
+                  break;
+                }
+                case GRAYColorspace:
+                {
+                  (void) fprintf(stderr,"    gray: %g (%g)\n",
+                    channel_distortion[GrayChannel],(double) QuantumScale*
+                    channel_distortion[GrayChannel]);
+                  if (image->matte != MagickFalse)
+                    (void) fprintf(stderr,"    alpha: %g (%g)\n",
+                      channel_distortion[OpacityChannel],(double) QuantumScale*
+                      channel_distortion[OpacityChannel]);
+                  break;
+                }
+              }
+              (void) fprintf(stderr,"    all: %g (%g)\n",
+                channel_distortion[AllChannels],(double) QuantumScale*
+                channel_distortion[AllChannels]);
+              break;
+            }
+            case AbsoluteErrorMetric:
+            case PeakSignalToNoiseRatioMetric:
+            {
+              switch (image->colorspace)
+              {
+                case RGBColorspace:
+                default:
+                {
+                  (void) fprintf(stderr,"    red: %g\n",
+                    channel_distortion[RedChannel]);
+                  (void) fprintf(stderr,"    green: %g\n",
+                    channel_distortion[GreenChannel]);
+                  (void) fprintf(stderr,"    blue: %g\n",
+                    channel_distortion[BlueChannel]);
+                  if (image->matte != MagickFalse)
+                    (void) fprintf(stderr,"    alpha: %g\n",
+                      channel_distortion[OpacityChannel]);
+                  break;
+                }
+                case CMYKColorspace:
+                {
+                  (void) fprintf(stderr,"    cyan: %g\n",
+                    channel_distortion[CyanChannel]);
+                  (void) fprintf(stderr,"    magenta: %g\n",
+                    channel_distortion[MagentaChannel]);
+                  (void) fprintf(stderr,"    yellow: %g\n",
+                    channel_distortion[YellowChannel]);
+                  (void) fprintf(stderr,"    black: %g\n",
+                    channel_distortion[BlackChannel]);
+                  if (image->matte != MagickFalse)
+                    (void) fprintf(stderr,"    alpha: %g\n",
+                      channel_distortion[OpacityChannel]);
+                  break;
+                }
+                case GRAYColorspace:
+                {
+                  (void) fprintf(stderr,"    gray: %g\n",
+                    channel_distortion[GrayChannel]);
+                  if (image->matte != MagickFalse)
+                    (void) fprintf(stderr,"    alpha: %g\n",
+                      channel_distortion[OpacityChannel]);
+                  break;
+                }
+              }
+              (void) fprintf(stderr,"    all: %g\n",
+                channel_distortion[AllChannels]);
+              break;
+            }
+            case MeanErrorPerPixelMetric:
+            {
+              (void) fprintf(stderr,"    %g (%g, %g)\n",
+                channel_distortion[AllChannels],
+                image->error.normalized_mean_error,
+                image->error.normalized_maximum_error);
+              break;
+            }
+            case UndefinedMetric:
+              break;
+          }
+          channel_distortion=(double *) RelinquishMagickMemory(
+            channel_distortion);
         }
-        case MeanErrorPerPixelMetric:
-        {
-          (void) fprintf(stderr,"%g (%g, %g)\n",distortion,
-            image->error.normalized_mean_error,
-            image->error.normalized_maximum_error);
-          break;
-        }
-        case UndefinedMetric:
-          break;
-      }
     }
   DestroyCompare();
   return(status != 0 ? MagickTrue : MagickFalse);
