@@ -286,7 +286,7 @@ static void CompositeUsage(void)
       "-density geometry    horizontal and vertical density of the image",
       "-display server      get image or font from this X server",
       "-dispose method      layer disposal method",
-      "-dither              apply Floyd/Steinberg error diffusion to image",
+      "-dither method       apply error diffusion to image",
       "-encoding type       text encoding type",
       "-endian type         endianness (MSB or LSB) of the image",
       "-filter type         use this filter when resizing an image",
@@ -300,6 +300,7 @@ static void CompositeUsage(void)
       "-limit type value    pixel cache resource limit",
       "-monitor             monitor progress",
       "-page geometry       size and location of an image canvas (setting)",
+      "-pointsize value     font point size",
       "-quality value       JPEG/MIFF/PNG compression level",
       "-quiet               suppress all warning messages",
       "-red-primary point   chromaticity red primary point",
@@ -860,8 +861,22 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
             composite_options.compose=DissolveCompositeOp;
             break;
           }
-        if (LocaleCompare("dither",option+1) == 0)
-          break;
+        if (LocaleCompare("method",option+1) == 0)
+          {
+            long
+              method;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowCompositeException(OptionError,"MissingArgument",option);
+            method=ParseMagickOption(MagickDitherOptions,MagickFalse,argv[i]);
+            if (method < 0)
+              ThrowCompositeException(OptionError,"UnrecognizedDitherMethod",
+                argv[i]);
+            break;
+          }
         ThrowCompositeException(OptionError,"UnrecognizedOption",option)
       }
       case 'e':
@@ -1124,6 +1139,17 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
               ThrowCompositeException(OptionError,"MissingArgument",option);
             break;
           }
+        if (LocaleCompare("pointsize",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowCompositeException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowCompositeInvalidArgumentException(option,argv[i]);
+            break;
+          }
         if (LocaleCompare("process",option+1) == 0)
           {
             if (*option == '+')
