@@ -329,7 +329,7 @@ static void ConvertUsage(void)
       "-depth value         image depth",
       "-display server      get image or font from this X server",
       "-dispose method      layer disposal method",
-      "-dither              apply Floyd/Steinberg error diffusion to image",
+      "-dither method       apply error diffusion to image",
       "-encoding type       text encoding type",
       "-endian type         endianness (MSB or LSB) of the image",
       "-family name         render text with this font family",
@@ -1140,7 +1140,7 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertException(OptionError,"MissingArgument",option);
             op=ParseMagickOption(MagickDistortOptions,MagickFalse,argv[i]);
             if (op < 0)
-              ThrowConvertException(OptionError,"UnrecognizedDistortType",
+              ThrowConvertException(OptionError,"UnrecognizedDistortMethod",
                 argv[i]);
             i++;
             if (i == (long) (argc-1))
@@ -1151,7 +1151,21 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
             break;
           }
         if (LocaleCompare("dither",option+1) == 0)
-          break;
+          {
+            long
+              method;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            method=ParseMagickOption(MagickDitherOptions,MagickFalse,argv[i]);
+            if (method < 0)
+              ThrowConvertException(OptionError,"UnrecognizedDitherMethod",
+                argv[i]);
+            break;
+          }
         if (LocaleCompare("draw",option+1) == 0)
           {
             if (*option == '+')
@@ -2298,7 +2312,7 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertException(OptionError,"MissingArgument",option);
             op=ParseMagickOption(MagickSparseColorOptions,MagickFalse,argv[i]);
             if (op < 0)
-              ThrowConvertException(OptionError,"UnrecognizedSparseColorType",
+              ThrowConvertException(OptionError,"UnrecognizedSparseColorMethod",
                 argv[i]);
             i++;
             if (i == (long) (argc-1))
