@@ -80,7 +80,7 @@
 %
 %  A description of each parameter follows:
 %
-%    o wand: The magick wand.
+%    o wand: the magick wand.
 %
 %    o pathname: name of clipping path resource. If name is preceded by #, use
 %      clipping path numbered by name.
@@ -114,7 +114,7 @@ WandExport MagickBooleanType MagickClipPathImage(MagickWand *wand,
 %
 %  A description of each parameter follows:
 %
-%    o wand: The drawing wand.
+%    o wand: the drawing wand.
 %
 */
 WandExport double DrawGetFillAlpha(const DrawingWand *wand)
@@ -141,7 +141,7 @@ WandExport double DrawGetFillAlpha(const DrawingWand *wand)
 %
 %  A description of each parameter follows:
 %
-%    o wand: The drawing wand.
+%    o wand: the drawing wand.
 */
 WandExport double DrawGetStrokeAlpha(const DrawingWand *wand)
 {
@@ -167,7 +167,7 @@ WandExport double DrawGetStrokeAlpha(const DrawingWand *wand)
 %
 %  A description of each parameter follows:
 %
-%    o wand: The drawing wand.
+%    o wand: the drawing wand.
 %
 */
 WandExport DrawInfo *DrawPeekGraphicWand(const DrawingWand *wand)
@@ -197,7 +197,7 @@ WandExport DrawInfo *DrawPeekGraphicWand(const DrawingWand *wand)
 %
 %  A description of each parameter follows:
 %
-%    o wand: The drawing wand.
+%    o wand: the drawing wand.
 %
 */
 WandExport void DrawPopGraphicContext(DrawingWand *wand)
@@ -217,7 +217,7 @@ WandExport void DrawPopGraphicContext(DrawingWand *wand)
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  DrawPushGraphicContext() clones the current drawing wand to create a new
-%  drawing wand.  The original drawing drawing wand(s) may be returned to by
+%  drawing wand.  The original drawing wand(s) may be returned to by
 %  invoking PopDrawingWand().  The drawing wands are stored on a drawing wand
 %  stack.  For every Pop there must have already been an equivalent Push.
 %
@@ -227,7 +227,7 @@ WandExport void DrawPopGraphicContext(DrawingWand *wand)
 %
 %  A description of each parameter follows:
 %
-%    o wand: The drawing wand.
+%    o wand: the drawing wand.
 %
 */
 WandExport void DrawPushGraphicContext(DrawingWand *wand)
@@ -255,7 +255,7 @@ WandExport void DrawPushGraphicContext(DrawingWand *wand)
 %
 %  A description of each parameter follows:
 %
-%    o wand: The drawing wand.
+%    o wand: the drawing wand.
 %
 %    o fill_alpha: fill alpha
 %
@@ -284,7 +284,7 @@ WandExport void DrawSetFillAlpha(DrawingWand *wand,const double fill_alpha)
 %
 %  A description of each parameter follows:
 %
-%    o wand: The drawing wand.
+%    o wand: the drawing wand.
 %
 %    o stroke_alpha: stroke alpha.  The value 1.0 is opaque.
 %
@@ -318,9 +318,9 @@ WandExport void DrawSetStrokeAlpha(DrawingWand *wand,const double stroke_alpha)
 %
 %  A description of each parameter follows:
 %
-%    o wand: The magick wand.
+%    o wand: the magick wand.
 %
-%    o fill: The floodfill color pixel wand.
+%    o fill: the floodfill color pixel wand.
 %
 %    o fuzz: By default target must match a particular pixel color
 %      exactly.  However, in many cases two colors may differ by a small amount.
@@ -329,9 +329,9 @@ WandExport void DrawSetStrokeAlpha(DrawingWand *wand,const double stroke_alpha)
 %      color red at intensities of 100 and 102 respectively are now interpreted
 %      as the same color for the purposes of the floodfill.
 %
-%    o bordercolor: The border color pixel wand.
+%    o bordercolor: the border color pixel wand.
 %
-%    o x,y: The starting location of the operation.
+%    o x,y: the starting location of the operation.
 %
 */
 WandExport MagickBooleanType MagickColorFloodfillImage(MagickWand *wand,
@@ -388,7 +388,7 @@ WandExport MagickBooleanType MagickColorFloodfillImage(MagickWand *wand,
 %
 %  A description of each parameter follows:
 %
-%    o wand: The magick wand.
+%    o wand: the magick wand.
 %
 */
 WandExport char *MagickDescribeImage(MagickWand *wand)
@@ -407,7 +407,7 @@ WandExport char *MagickDescribeImage(MagickWand *wand)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  MagickFlattenImages() merges a sequence of images.  This is useful for
+%  MagickFlattenImages() merges a sequence of images.  This useful for
 %  combining Photoshop layers into a single image.
 %
 %  The format of the MagickFlattenImages method is:
@@ -416,7 +416,7 @@ WandExport char *MagickDescribeImage(MagickWand *wand)
 %
 %  A description of each parameter follows:
 %
-%    o wand: The magick wand.
+%    o wand: the magick wand.
 %
 */
 
@@ -488,9 +488,9 @@ WandExport MagickWand *MagickFlattenImages(MagickWand *wand)
 %
 %  A description of each parameter follows:
 %
-%    o wand: The magick wand.
+%    o wand: the magick wand.
 %
-%    o property: The property.
+%    o property: the property.
 %
 */
 WandExport char *MagickGetImageAttribute(MagickWand *wand,const char *property)
@@ -517,7 +517,7 @@ WandExport char *MagickGetImageAttribute(MagickWand *wand,const char *property)
 %
 %  A description of each parameter follows:
 %
-%    o wand: The magick wand.
+%    o wand: the magick wand.
 %
 */
 WandExport long MagickGetImageIndex(MagickWand *wand)
@@ -546,9 +546,9 @@ WandExport long MagickGetImageIndex(MagickWand *wand)
 %
 %  A description of each parameter follows:
 %
-%    o wand: The magick wand.
+%    o wand: the magick wand.
 %
-%    o channel: The image channel(s).
+%    o channel: the image channel(s).
 %
 %    o minima:  The minimum pixel value for the specified channel(s).
 %
@@ -592,7 +592,7 @@ WandExport MagickBooleanType MagickGetImageChannelExtrema(MagickWand *wand,
 %
 %  A description of each parameter follows:
 %
-%    o wand: The magick wand.
+%    o wand: the magick wand.
 %
 %    o minima:  The minimum pixel value for the specified channel(s).
 %
@@ -620,6 +620,40 @@ WandExport MagickBooleanType MagickGetImageExtrema(MagickWand *wand,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   M a g i c k G e t I m a g e M a t t e                                     %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MagickGetImageMatte() returns MagickTrue if the image has a matte channel
+%  otherwise MagickFalse.
+%
+%  The format of the MagickGetImageMatte method is:
+%
+%      unsigned long MagickGetImageMatte(MagickWand *wand)
+%
+%  A description of each parameter follows:
+%
+%    o wand: the magick wand.
+%
+*/
+WandExport MagickBooleanType MagickGetImageMatte(MagickWand *wand)
+{
+  assert(wand != (MagickWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  if (wand->images == (Image *) NULL)
+    ThrowWandException(WandError,"ContainsNoImages",wand->name);
+  return(wand->images->matte);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   M a g i c k M a t t e F l o o d f i l l I m a g e                         %
 %                                                                             %
 %                                                                             %
@@ -639,9 +673,9 @@ WandExport MagickBooleanType MagickGetImageExtrema(MagickWand *wand,
 %
 %  A description of each parameter follows:
 %
-%    o wand: The magick wand.
+%    o wand: the magick wand.
 %
-%    o alpha: The level of transparency: 1.0 is fully opaque and 0.0 is fully
+%    o alpha: the level of transparency: 1.0 is fully opaque and 0.0 is fully
 %      transparent.
 %
 %    o fuzz: By default target must match a particular pixel color
@@ -651,9 +685,9 @@ WandExport MagickBooleanType MagickGetImageExtrema(MagickWand *wand,
 %      color red at intensities of 100 and 102 respectively are now interpreted
 %      as the same color for the purposes of the floodfill.
 %
-%    o bordercolor: The border color pixel wand.
+%    o bordercolor: the border color pixel wand.
 %
-%    o x,y: The starting location of the operation.
+%    o x,y: the starting location of the operation.
 %
 */
 WandExport MagickBooleanType MagickMatteFloodfillImage(MagickWand *wand,
@@ -711,7 +745,7 @@ WandExport MagickBooleanType MagickMatteFloodfillImage(MagickWand *wand,
 %
 %  A description of each parameter follows:
 %
-%    o wand: The magick wand.
+%    o wand: the magick wand.
 %
 */
 WandExport MagickWand *MagickMosaicImages(MagickWand *wand)
@@ -752,13 +786,13 @@ WandExport MagickWand *MagickMosaicImages(MagickWand *wand)
 %
 %  A description of each parameter follows:
 %
-%    o wand: The magick wand.
+%    o wand: the magick wand.
 %
-%    o channel: The channel(s).
+%    o channel: the channel(s).
 %
 %    o target: Change this target color to the fill color within the image.
 %
-%    o fill: The fill pixel wand.
+%    o fill: the fill pixel wand.
 %
 %    o fuzz: By default target must match a particular pixel color
 %      exactly.  However, in many cases two colors may differ by a small amount.
@@ -798,11 +832,11 @@ WandExport MagickBooleanType MagickOpaqueImage(MagickWand *wand,
 %
 %  A description of each parameter follows:
 %
-%    o wand: The magick wand.
+%    o wand: the magick wand.
 % 
-%    o channel: The channel(s).
+%    o channel: the channel(s).
 %
-%    o fill: The floodfill color pixel wand.
+%    o fill: the floodfill color pixel wand.
 %
 %    o fuzz: By default target must match a particular pixel color
 %      exactly.  However, in many cases two colors may differ by a small amount.
@@ -811,9 +845,9 @@ WandExport MagickBooleanType MagickOpaqueImage(MagickWand *wand,
 %      color red at intensities of 100 and 102 respectively are now interpreted
 %      as the same color for the purposes of the floodfill.
 %
-%    o bordercolor: The border color pixel wand.
+%    o bordercolor: the border color pixel wand.
 %
-%    o x,y: The starting location of the operation.
+%    o x,y: the starting location of the operation.
 %
 */
 WandExport MagickBooleanType MagickPaintFloodfillImage(MagickWand *wand,
@@ -852,13 +886,13 @@ WandExport MagickBooleanType MagickPaintFloodfillImage(MagickWand *wand,
 %
 %  A description of each parameter follows:
 %
-%    o wand: The magick wand.
+%    o wand: the magick wand.
 %
-%    o channel: The channel(s).
+%    o channel: the channel(s).
 %
 %    o target: Change this target color to the fill color within the image.
 %
-%    o fill: The fill pixel wand.
+%    o fill: the fill pixel wand.
 %
 %    o fuzz: By default target must match a particular pixel color
 %      exactly.  However, in many cases two colors may differ by a small amount.
@@ -908,12 +942,12 @@ WandExport MagickBooleanType MagickPaintOpaqueImageChannel(MagickWand *wand,
 %
 %  A description of each parameter follows:
 %
-%    o wand: The magick wand.
+%    o wand: the magick wand.
 %
 %    o target: Change this target color to specified opacity value within
 %      the image.
 %
-%    o alpha: The level of transparency: 1.0 is fully opaque and 0.0 is fully
+%    o alpha: the level of transparency: 1.0 is fully opaque and 0.0 is fully
 %      transparent.
 %
 %    o fuzz: By default target must match a particular pixel color
@@ -950,11 +984,11 @@ WandExport MagickBooleanType MagickPaintTransparentImage(MagickWand *wand,
 %
 %  A description of each parameter follows:
 %
-%    o wand: The magick wand.
+%    o wand: the magick wand.
 %
-%    o property: The property.
+%    o property: the property.
 %
-%    o value: The value.
+%    o value: the value.
 %
 */
 WandExport MagickBooleanType MagickSetImageAttribute(MagickWand *wand,
@@ -983,9 +1017,9 @@ WandExport MagickBooleanType MagickSetImageAttribute(MagickWand *wand,
 %
 %  A description of each parameter follows:
 %
-%    o wand: The magick wand.
+%    o wand: the magick wand.
 %
-%    o index: The scene number.
+%    o index: the scene number.
 %
 */
 WandExport MagickBooleanType MagickSetImageIndex(MagickWand *wand,
@@ -1015,9 +1049,9 @@ WandExport MagickBooleanType MagickSetImageIndex(MagickWand *wand,
 %
 %  A description of each parameter follows:
 %
-%    o wand: The magick wand.
+%    o wand: the magick wand.
 %
-%    o format: The image format.
+%    o format: the image format.
 %
 %    o key:  The key.
 %
@@ -1059,12 +1093,12 @@ WandExport MagickBooleanType MagickSetImageOption(MagickWand *wand,
 %
 %  A description of each parameter follows:
 %
-%    o wand: The magick wand.
+%    o wand: the magick wand.
 %
 %    o target: Change this target color to specified opacity value within
 %      the image.
 %
-%    o alpha: The level of transparency: 1.0 is fully opaque and 0.0 is fully
+%    o alpha: the level of transparency: 1.0 is fully opaque and 0.0 is fully
 %      transparent.
 %
 %    o fuzz: By default target must match a particular pixel color
@@ -1093,7 +1127,7 @@ WandExport MagickBooleanType MagickTransparentImage(MagickWand *wand,
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  MagickRegionOfInterestImage() extracts a region of the image and returns it
-%  as a a new wand.
+%  as a new wand.
 %
 %  The format of the MagickRegionOfInterestImage method is:
 %
@@ -1103,15 +1137,15 @@ WandExport MagickBooleanType MagickTransparentImage(MagickWand *wand,
 %
 %  A description of each parameter follows:
 %
-%    o wand: The magick wand.
+%    o wand: the magick wand.
 %
-%    o width: The region width.
+%    o width: the region width.
 %
-%    o height: The region height.
+%    o height: the region height.
 %
-%    o x: The region x offset.
+%    o x: the region x offset.
 %
-%    o y: The region y offset.
+%    o y: the region y offset.
 %
 */
 WandExport MagickWand *MagickRegionOfInterestImage(MagickWand *wand,
@@ -1141,9 +1175,9 @@ WandExport MagickWand *MagickRegionOfInterestImage(MagickWand *wand,
 %
 %  A description of each parameter follows:
 %
-%    o wand: The magick wand.
+%    o wand: the magick wand.
 %
-%    o length: The image length in bytes.
+%    o length: the image length in bytes.
 %
 */
 WandExport MagickSizeType MagickGetImageSize(MagickWand *wand)
@@ -1180,9 +1214,9 @@ WandExport MagickSizeType MagickGetImageSize(MagickWand *wand)
 %
 %  A description of each parameter follows:
 %
-%    o wand: The magick wand.
+%    o wand: the magick wand.
 %
-%    o length: The length of the blob.
+%    o length: the length of the blob.
 %
 */
 WandExport unsigned char *MagickWriteImageBlob(MagickWand *wand,size_t *length)
@@ -1210,9 +1244,9 @@ WandExport unsigned char *MagickWriteImageBlob(MagickWand *wand,size_t *length)
 %
 %  A description of each parameter follows:
 %
-%    o wand: The magick wand.
+%    o wand: the magick wand.
 %
-%    o method: The image virtual pixel method : UndefinedVirtualPixelMethod,
+%    o method: the image virtual pixel method : UndefinedVirtualPixelMethod,
 %      ConstantVirtualPixelMethod,  EdgeVirtualPixelMethod,
 %      MirrorVirtualPixelMethod, or TileVirtualPixelMethod.
 %
@@ -1250,9 +1284,9 @@ WandExport VirtualPixelMethod MagickSetImageVirtualPixelMethod(MagickWand *wand,
 %
 %  A description of each parameter follows:
 %
-%    o iterator: The pixel iterator.
+%    o iterator: the pixel iterator.
 %
-%    o number_wands: The number of pixel wands.
+%    o number_wands: the number of pixel wands.
 %
 */
 WandExport PixelWand **PixelGetNextRow(PixelIterator *iterator)
@@ -1284,9 +1318,9 @@ WandExport PixelWand **PixelGetNextRow(PixelIterator *iterator)
 %
 %  A description of each parameter follows:
 %
-%    o iterator: The pixel iterator.
+%    o iterator: the pixel iterator.
 %
-%    o severity: The severity of the error is returned here.
+%    o severity: the severity of the error is returned here.
 %
 */
 WandExport char *PixelIteratorGetException(const PixelIterator *iterator,
