@@ -128,6 +128,7 @@ static void DisplayUsage(void)
       "-flip                flip image in the vertical direction",
       "-flop                flop image in the horizontal direction",
       "-frame geometry      surround image with an ornamental border",
+      "-fuzz distance       colors within this distance are considered equal",
       "-gamma value         level of gamma correction",
       "-monochrome          transform image to black and white",
       "-negate              replace every pixel with its complementary color",
@@ -163,7 +164,7 @@ static void DisplayUsage(void)
       "-depth value         image depth",
       "-display server      display image to this X server",
       "-dispose method      layer disposal method",
-      "-dither              apply Floyd/Steinberg error diffusion to image",
+      "-dither method       apply error diffusion to image",
       "-endian type         endianness (MSB or LSB) of the image",
       "-filter type         use this filter when resizing an image",
       "-format \"string\"     output formatted image characteristics",
@@ -1014,7 +1015,21 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("dither",option+1) == 0)
           {
-            quantize_info->dither=(*option == '-') ? MagickTrue : MagickFalse;
+            long
+              method;
+
+            quantize_info->dither=MagickFalse;
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowDisplayException(OptionError,"MissingArgument",option);
+            method=ParseMagickOption(MagickDitherOptions,MagickFalse,argv[i]);
+            if (method < 0)
+              ThrowDisplayException(OptionError,"UnrecognizedDitherMethod",
+                argv[i]);
+            quantize_info->dither=MagickTrue;
+            quantize_info->dither_method=(DitherMethod) method;
             break;
           }
         ThrowDisplayException(OptionError,"UnrecognizedOption",option);
@@ -1129,6 +1144,17 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
               ThrowDisplayInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("fuzz",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowDisplayException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowDisplayInvalidArgumentException(option,argv[i]);
+            break;
+          }
         ThrowDisplayException(OptionError,"UnrecognizedOption",option);
       }
       case 'g':
