@@ -147,7 +147,7 @@ static void ImportUsage(void)
       "-descend             obtain image by descending window hierarchy",
       "-display server      X server to contact",
       "-dispose method      layer disposal method",
-      "-dither              apply Floyd/Steinberg error diffusion to image",
+      "-dither method       apply error diffusion to image",
       "-delay value         display the next image after pausing",
       "-encipher filename   convert plain pixels to cipher pixels",
       "-endian type         endianness (MSB or LSB) of the image",
@@ -721,7 +721,21 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("dither",option+1) == 0)
           {
-            quantize_info->dither=(*option == '-') ? MagickTrue : MagickFalse;
+            long
+              method;
+
+            quantize_info->dither=MagickFalse;
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowImportException(OptionError,"MissingArgument",option);
+            method=ParseMagickOption(MagickDitherOptions,MagickFalse,argv[i]);
+            if (method < 0)
+              ThrowImportException(OptionError,"UnrecognizedDitherMethod",
+                argv[i]);
+            quantize_info->dither=MagickTrue;
+            quantize_info->dither_method=(DitherMethod) method;
             break;
           }
         ThrowImportException(OptionError,"UnrecognizedOption",option);
