@@ -45,6 +45,8 @@ extern WandExport DisposeType
   MagickGetImageDispose(MagickWand *);
 
 extern WandExport double
+  *MagickGetImageChannelDistortions(MagickWand *,const MagickWand *,
+    const MetricType),
   MagickGetImageGamma(MagickWand *),
   MagickGetImageTotalInkDensity(MagickWand *);
 
@@ -110,6 +112,7 @@ extern WandExport MagickBooleanType
     const long,const long),
   MagickCycleColormapImage(MagickWand *,const long),
   MagickDecipherImage(MagickWand *,const char *),
+  MagickDeskewImage(MagickWand *,const double),
   MagickDespeckleImage(MagickWand *),
   MagickDisplayImage(MagickWand *,const char *),
   MagickDisplayImages(MagickWand *,const char *),
