@@ -137,7 +137,7 @@ static void MontageUsage(void)
       "-depth value         image depth",
       "-display server      query font from this X server",
       "-dispose method      layer disposal method",
-      "-dither              apply Floyd/Steinberg error diffusion to image",
+      "-dither method       apply error diffusion to image",
       "-draw string         annotate the image with a graphic primitive",
       "-encoding type       text encoding type",
       "-endian type         endianness (MSB or LSB) of the image",
@@ -295,9 +295,6 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
   MontageInfo
     *montage_info;
 
-  QuantizeInfo
-    quantize_info;
-
   register long
     i;
 
@@ -333,8 +330,6 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
   NewImageStack();
   option=(char *) NULL;
   pend=MagickFalse;
-  GetQuantizeInfo(&quantize_info);
-  quantize_info.number_colors=0;
   scene=0;
   status=MagickFalse;
   transparent_color=(char *) NULL;
@@ -612,7 +607,6 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
           break;
         if (LocaleCompare("colors",option+1) == 0)
           {
-            quantize_info.number_colors=0;
             if (*option == '+')
               break;
             i++;
@@ -620,7 +614,6 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
               ThrowMontageException(OptionError,"MissingArgument",option);
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowMontageInvalidArgumentException(option,argv[i]);
-            quantize_info.number_colors=(unsigned long) atol(argv[i]);
             break;
           }
         if (LocaleCompare("colorspace",option+1) == 0)
@@ -780,7 +773,18 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("dither",option+1) == 0)
           {
-            quantize_info.dither=(*option == '-') ? MagickTrue : MagickFalse;
+            long
+              method;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowMontageException(OptionError,"MissingArgument",option);
+            method=ParseMagickOption(MagickDitherOptions,MagickFalse,argv[i]);
+            if (method < 0)
+              ThrowMontageException(OptionError,"UnrecognizedDitherMethod",
+                argv[i]);
             break;
           }
         if (LocaleCompare("draw",option+1) == 0)
@@ -1110,8 +1114,6 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
           {
             if (*option == '+')
               break;
-            quantize_info.number_colors=2;
-            quantize_info.colorspace=GRAYColorspace;
             break;
           }
         ThrowMontageException(OptionError,"UnrecognizedOption",option)
@@ -1486,7 +1488,6 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("treedepth",option+1) == 0)
           {
-            quantize_info.tree_depth=0;
             if (*option == '+')
               break;
             i++;
@@ -1494,7 +1495,6 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
               ThrowMontageException(OptionError,"MissingArgument",option);
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowMontageInvalidArgumentException(option,argv[i]);
-            quantize_info.tree_depth=(unsigned long) atol(argv[i]);
             break;
           }
         if (LocaleCompare("trim",option+1) == 0)
