@@ -189,9 +189,6 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
   const char
     *format;
 
-  ChannelType
-    channel;
-
   Image
     *image;
 
@@ -238,7 +235,6 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
     }
   if (argc < 3)
     StreamUsage();
-  channel=AllChannels;
   format="%w,%h,%m";
   j=1;
   k=0;
